@@ -309,79 +309,95 @@
            (d-SetSaved #f))))      
         
         
-(define* (SetDirectiveConditionalOnCondition criteria #:optional (directive #f) (type/tag #f) (action 'omit))
-  (define criterion (RadioBoxMenuList criteria))
-  (if criterion
-    (begin
-      ;;;it would be nice to check here if "criterion" was already in the list of "layouts" attached to directive, but this would require a new fleet of functions to enquire, one for each type of directive...
-      (if type/tag 
-        (begin
-          ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-ignore")) (cdr type/tag)  
-                                        criterion)
-          (d-SetSaved #f))
-        (if (pair? directive)                                
-          (begin
-            (disp "pair Not Implemented\n\n\n"))
-          (begin (disp "criterion " criterion " being set/unset for " action "\n\n")
-            (if (eq? action 'omit)
-              (d-DirectivePut-standalone-ignore (d-DirectiveGetTag-standalone) criterion)
-              (d-DirectivePut-standalone-allow (d-DirectiveGetTag-standalone) criterion))
-            (d-SetSaved #f)))))))
-        
-        
-        
-                                   
-(define* (SetDirectiveConditional #:optional (directive #f) (type/tag #f))
- (define choice #f)
- (define criteria (d-GetOmitCriteria))
- (if (not (null? criteria))
-    (set! choice
-          (RadioBoxMenu 
-            (cons (_ "Conditional on Layout") #f)
-            (cons (_ "Omit for an Omission Criterion") 'omit)
-            (cons (_ "Allow when Omission Criterion set") 'drop))))
-  (if choice
-      (SetDirectiveConditionalOnCondition criteria directive type/tag choice) 
-      (SetDirectiveConditionalOnLayout directive type/tag)))
+(define* (SetDirectiveConditionalOnCondition criteria type tag action)
+  (define not-active criteria)
+  (define remaining criteria)
+  (define criterion 0)
+  (define attached (d-GetIncludeCriteriaOnDirective tag type))
+  (let loop ((thelist attached))
+			(if (not (null? thelist))
+				(begin
+					(set! remaining (remove (lambda (elem) (equal? (car thelist) (car elem)))
+										 remaining))
+					(loop (cdr thelist))))
+			(set! not-active remaining))
+  (case action
+	((include)
+					(set! criteria not-active))
+	((drop)				
+		(let loop ((thelist not-active))
+					(if (and (not (null? criteria)) (not (null? thelist)))
+						(begin
+							(set! criteria (delete (car thelist) criteria))
+							(loop (cdr thelist)))))))
+  (if (and (eq? action 'include)(null? not-active))
+	(d-WarningDialog (_ "All inclusion criteria are set on this directive"))
+	(if (not (null? criteria))
+	   (begin
+		  (set! criterion (RadioBoxMenuList criteria))
+		  (if criterion
+			(begin 
+			 (if (eq? action 'include)
+				((eval-string (string-append "d-DirectivePut-" type "-ignore")) tag  
+												criterion)
+				((eval-string (string-append "d-DirectivePut-" type "-allow")) tag  
+												criterion))
+				  (d-SetSaved #f))
+			 (d-WarningDialog (_ "Cancelled"))))
+		(d-WarningDialog (_ "No inclusion criterion is set on this directive")))))
+
+                
+(define* (SetDirectiveConditional type tag)
+	(if tag
+		(let ((choice #f) (criteria (d-GetIncludeCriteria)))
+			(set! choice
+				  (RadioBoxMenu 
+					(cons (_ "Conditional on Layout") 'layout)
+					(cons (string-append tag (_ ": For all layouts")) 'all)
+					(cons (_ "Only when an Inclusion Criterion set") 'include)
+					(cons (_ "Drop an Inclusion Criterion") 'drop)))
+			  (case choice
+				((layout)
+					(SetDirectiveConditionalOnLayout type tag))
+				((all)
+					((eval-string (string-append "d-DirectivePut-" type "-ignore")) tag 0)
+					((eval-string (string-append "d-DirectivePut-" type "-allow")) tag 0))
+				((include)
+					(if (null? criteria)
+						(begin
+							(set! criteria (d-CreateIncludeCriterion))))
+					(if (not (null? criteria))
+						(SetDirectiveConditionalOnCondition criteria type tag choice)
+						(d-WarningDialog (_ "Cancelled"))))
+				((drop)
+					(SetDirectiveConditionalOnCondition criteria type tag choice))))
+		(d-WarningDialog (_ "No Denemo Directive here"))))
 
-(define* (SetDirectiveConditionalOnLayout #:optional (directive #f) (type/tag #f))
-    (define choice (if (equal? (d-StaffProperties "query=lily_name") (d-GetLayoutName))
-                        (RadioBoxMenu
-                            (cons (string-append (_ "Allow for Layout \"") (d-GetLayoutName) "\"") 'default)
-                            (cons (string-append (_ "Ignore for Layout \"") (d-GetLayoutName) "\"") 'ignore-default)
-                            (cons (_ "For all Layouts") 'all))
-                        (RadioBoxMenu
-                            (cons (string-append (_ "Allow for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'only)   
-                            (cons (string-append (_ "Ignore for the Layout for Part \"") (d-StaffProperties "query=lily_name") "\"")   'ignore-only)   
-                            (cons (string-append (_ "Allow for Layout \"") (d-GetLayoutName) "\"") 'default)
-                            (cons (string-append (_ "Ignore for Layout \"") (d-GetLayoutName) "\"") 'ignore-default)
-                            (cons (_ "For all Layouts") 'all))))
             
-     (if type/tag 
-            (case choice
-                    ((ignore-only) ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-ignore")) (cdr type/tag)  
-                                    (d-GetCurrentStaffLayoutId)))
-                    ((ignore-default) ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-ignore")) (cdr type/tag)  
-                                    (d-GetLayoutId)))
-                    ((all) ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-ignore")) (cdr type/tag)   0)
-                            ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-allow")) (cdr type/tag)   0))
-                    ((default) ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-allow")) (cdr type/tag) 
-                            (d-GetLayoutId)))
-                    ((only) ((eval-string (string-append "d-DirectivePut-" (car type/tag) "-allow")) (cdr type/tag) 
-                            (d-GetCurrentStaffLayoutId))))
-            (if (pair? directive)
-                (case choice
-                    ((ignore-only) (d-DirectiveNotForLayout (cons (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId)) directive))) 
-                    ((ignore-default)  (d-DirectiveNotForLayout (cons (cons (d-GetLayoutName) (d-GetLayoutId))directive)))
-                    ((all) (d-DirectiveForAllLayouts directive))
-                    ((default) (d-DirectiveOnlyForLayout (cons (cons (d-GetLayoutName) (d-GetLayoutId)) directive)))
-                    ((only) (d-DirectiveOnlyForLayout  (cons (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId)) directive))))
-                (case choice
-                    ((ignore-only) (d-NotForLayout (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId))))
-                    ((ignore-default) (d-NotForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
-                    ((all) (d-ForAllLayouts))
-                    ((default) (d-OnlyForLayout (cons (d-GetLayoutName) (d-GetLayoutId))))
-                    ((only) (d-OnlyForLayout (cons (d-StaffProperties "query=lily_name") (d-GetCurrentStaffLayoutId))))))))
+(define* (SetDirectiveConditionalOnLayout type tag)
+		(define allow-or-ignore 
+						(RadioBoxMenu
+							
+							(cons (string-append tag (_ ": Allow for a layout")) "allow")
+							(cons (string-append tag (_ ": Ignore for a layout")) "ignore")))
+		(define thelist (GetLayoutList))
+		(define choiceId #f)
+		(if allow-or-ignore
+			(if (eq? allow-or-ignore 'all)
+				(begin
+					((eval-string (string-append "d-DirectivePut-" type "-ignore")) tag 0)
+					((eval-string (string-append "d-DirectivePut-" type "-allow")) tag 0))
+				(begin	
+					(set! choiceId (RadioBoxMenuList 
+						(map-in-order (lambda (layout)
+										(cons (string-append allow-or-ignore " for " (car layout)) (cdr layout)))
+									   thelist)))
+					(if choiceId
+						
+							((eval-string (string-append "d-DirectivePut-" type "-" allow-or-ignore)) tag  
+														choiceId))))
+			(d-WarningDialog (_ "Cancelled"))))
+		   
 
 ;;; Toggle the DENEMO_OVERRIDE_HIDDEN override of the directive at the cursor
 (define (ToggleHidden type tag) ;;; eg (ToggleHidden "note" "Fingering")
