@@ -411,6 +411,45 @@
 (define (DenemoPlay)
   (DefaultDenemoPlay))
 
+;Scripted start stop - use on Windows.
+(define-once DenemoPaused? #f)
+(define-once DenemoPauseTime 0) ;time to start playing at when un-pausing
+(define-once DenemoPlayTime #f) ;time to start playing at when re-starting from beginning
+(define (DenemoAltPlay) 
+	(define playhead (d-AudioIsPlaying))
+	(if DenemoPaused?
+		(begin
+			(set! DenemoPaused? #f)
+			(if (not DenemoPlayTime)
+				(set! DenemoPlayTime (d-AdjustPlaybackStart 0.0)))
+			(d-SetPlaybackInterval DenemoPauseTime #f)
+			(d-Play "(disp \"Stopped play after pause\")(d-SetPlaybackInterval DenemoPauseTime #f)"))
+		(begin
+				(if playhead 
+					(begin ;pressing play while playing and not paused => pause
+						(d-Stop)
+						(if (not DenemoPlayTime)
+							(set! DenemoPlayTime (d-AdjustPlaybackStart 0.0)))
+						(set! DenemoPauseTime playhead)
+						  (d-SetPlaybackInterval DenemoPauseTime #f)
+						(set! DenemoPaused? #t))
+					(begin ;;pressing play when not playing
+						(if (not DenemoPaused?)
+							(begin
+								(set! DenemoPlayTime (d-AdjustPlaybackStart 0.0))
+								(d-Play "(disp \"Finished play from playback start\"  DenemoPlayTime  DenemoPaused?  DenemoPauseTime\"\\n\\n\"      )"))))))))
+	
+(define (DenemoAltStop)
+	(if (not DenemoPlayTime)
+		(set! DenemoPlayTime (d-AdjustPlaybackStart 0.0)))
+   (d-SetPlaybackInterval DenemoPlayTime #f)
+	(if DenemoPaused?
+			(set! DenemoPaused? #f)
+		(begin
+			(set! Playback::Loop #f)
+			(d-Stop))))
+
+
 (define (DenemoPause)
   (begin
     (display "DenemoPause")))
@@ -548,7 +587,11 @@
   (d-PopPosition)
   offtime)
   
-(define DenemoClickTrack (_ "Click Track")) 
+;;(define DenemoClickTrack ... this is defined to be DENEMO_CLICK_TRACK_NAME in C, the value is "Click"
+
+;RemoveClickTracks from all movements
+(define (RemoveClickTracks)
+	(ForAllMovements "(d-GoToPosition #f 1 1 1)(if (d-Directive-clef? DenemoClickTrack) (d-DeleteStaff))"))
 
 ;;;
 (define d-GetOnsetTime d-GetMidiOnTime)  ;;;was a duplicate, not used by Denemo
@@ -861,6 +904,12 @@
 (define (d-Change-3072) (d-ChangeBreve))
 (define (d-Change-6411) (d-ChangeLonga))
 
+(define-once Snippet::Breve 0)
+(define-once Snippet::Longa 0)
+(define-once Snippet::Maxima 0)
+
+
+
 ;Insert a no-pitch note of the prevailing duration.
 (define (d-Enter) (eval-string (string-append "(d-" (number->string (abs (d-GetPrevailingDuration))) ")" )))
 
@@ -1353,7 +1402,7 @@
                             (d-DirectiveGet-header-postfix "MovementPiece"))
                         (begin
                             (set! choice 'abort)
-                            (d-WarningDialog (_ "You have simple titles created by an earlier version of Denemo.\nYou can only edit these with 1.2.4 or earlier versions.\nYou can delete them in the score and movement editor and then re-instate them."))))))
+                            (d-WarningDialog (_ "You have simple titles created by an earlier version of Denemo.\nYou can only edit these with 1.2.4 or earlier versions.\nYou can delete them in the score and movement editor and then re-instate them. You must also delete the Directive \"PrintAllHeaders\" in the Score Properties Editor when you do this."))))))
                 
  
             (case choice
@@ -1442,7 +1491,40 @@
                 (d-SetSaved #f)
                 (d-DirectivePut-paper-data tag data)
                 (d-DirectivePut-paper-postfix tag (string-append type ".basic-distance =  " data "\n"))))))
-                
+;;;;;;;;;;;
+;example: (begin (DenemoSpacingParams  "MarkupSystemSpacing" "markup-system-spacing" 'stretchability 1) (DenemoSpacingParams "SystemSystemSpacing"  "system-system-spacing" 'stretchability 1))                
+(define* (DenemoSpacingParams tag elements type #:optional (value #f))
+    (let* ((data #f)(title #f)(prompt #f)
+			(basic-distance 12)
+			(minimum-distance 8)
+			(padding 1)
+			(stretchability 60))
+		(set! tag (string-append tag "-" (symbol->string type)))
+		(set! data (d-DirectiveGet-paper-data tag))
+		(case type
+			((basic-distance)
+				(set! prompt (_ "Give distance"))
+				(set! title (_ (string-append tag " Basic Distance"))))
+			((minimum-distance)
+				(set! prompt (_ "Give distance"))
+				(set! title (_ "System to System Minimum Distance")))
+			((padding)
+				(set! prompt (_ "Give padding"))
+				(set! title (_ "System to System Padding")))
+			((stretchability)
+				(set! prompt (_ "Give stretchability"))
+				(set! title (_ "System to System Stretchability"))))		
+		
+        (if value
+			(set! value (number->string value))
+			(set! value (d-GetUserInput title prompt data)))
+        (if (and value (string->number value))
+            (begin
+                (d-SetSaved #f)
+                (d-DirectivePut-paper-data tag value)
+                (d-DirectivePut-paper-postfix tag (string-append elements "." (symbol->string type) " = " value "\n"))))))                
+ 
+                                
 ;;;;edit staff, called from tools icon at start of staff
 (define (EditStaff)
         (let* ((num (number->string (d-GetStaff)))(choice (RadioBoxMenu 
@@ -1456,23 +1538,26 @@
             (if (d-StaffHidden)
                 (cons  (string-append (_ "(Display) Show Staff") " " num) 'display)
                 (cons  (string-append (_ "(Display) Hide Staff") " " num) 'display))
-                
+            (cons (_ "(Display) Auto Adjust Staff Height") 'reset)    
             (cons (_ "Built-in Staff Properties") 'editor))))
         (case choice
             ((mute) (d-MuteStaff))
             ((show) (d-NonPrintingStaff))
             ((display) (d-ToggleCurrentStaffDisplay))
+            ((reset) (begin (d-InfoDialog (_ "Staff spacing will be automatically adjusted"))(d-StaffSetSpaceAbove -1)))
             ((editor) (d-StaffProperties)))))
-;;;;edit staff, called from tools icon at start of staff
+;;;;edit movement, called from tools icon at top left of display area
 (define (EditMovement)
         (let* ((choice (RadioBoxMenu 
             (cons (_ "Help") 'help)
+            (cons (_ "Movement Tempo") 'tempo)
             (cons (_ "Mute Staffs") 'mute)
             (cons (_ "(Display) Show All Staffs") 'show)
             (cons (_ "(Display) Hide All Other Staffs") 'hide)
             (cons (_ "Movement Editor") 'editor))))
         (case choice
             ((help) (d-InfoDialog (_ "This sets the visibility/mute and other properties for the whole movement")))
+            ((tempo) (d-MovementTempo))
             ((mute) (d-MuteStaffs))
             ((show) (StaffsVisibility #t))
             ((hide)  (StaffsVisibility #f))
@@ -1761,3 +1846,43 @@
                                   "\"\"Filename: " short-file "\"}\n"
                         "\\noPageBreak\\markup {\\column {\\draw-hline}}"))
             "\\markup { BLANK ENTRY }"))
+            
+;;moves to next movement skipping sketches, stops at last movement if it is a sketch            
+(define (NextNonSketchMovement)
+	(if (d-NextMovement)
+		(begin
+			(d-ToggleSketch)
+			(if (d-ToggleSketch)
+				(NextNonSketchMovement)
+				#t))
+		#f))
+;;gets a list of all layouts in Score Layout view together with the default one for the current part
+(define (GetLayoutList)
+	(let ((thelist '())(start (d-GetLayoutId))(partid #f))
+	(define (addtolist name id)
+		(if (not (equal? id partid))
+			(set! thelist (cons (cons name id) thelist))))
+	(set! partid (d-GetCurrentStaffLayoutId))
+	(d-SelectFirstLayout)
+	(addtolist (d-GetLayoutName) (d-GetLayoutId))
+	(while (d-SelectNextLayout)
+		(addtolist (d-GetLayoutName) (d-GetLayoutId)))
+	(if partid
+			(set! thelist (cons (cons (d-StaffProperties "query=lily_name") partid) thelist)))
+	(d-SelectLayoutId start)
+	thelist))
+
+(define-once MasterMute::value #f) ;saved value for MasterVolume when muted between (MasterMute #t) and (MasterMute #f)	
+(define (MasterMute mute)
+		(if (and mute (not MasterMute::value))
+			(begin
+				(set! MasterMute::value (d-MasterVolume))
+				(d-MasterVolume 0))
+			(begin
+				(if MasterMute::value
+					(d-MasterVolume MasterMute::value)
+					(d-MasterVolume 1))
+				(set! MasterMute::value #f))))
+	
+(define (ToggleViewVisibility name)
+	(d-SetViewVisibility name (not (d-GetViewVisibility name))))	
