@@ -14,11 +14,13 @@
 				(if (d-StaffHidden)
 					(set! hide #f)))
 			(d-PopPosition)
+			(d-PushPosition)
 			(while (d-MoveToStaffDown)
 				(if (d-StaffHidden)
-					(set! hide #f)))
+					(set! hide #f))) ;; hide is now #f if there are other hidden staffs
+			(d-GoToPosition #f 1 1 1)
 			(d-StaffHidden hide)
-			(while (d-MoveToStaffUp)
+			(while (d-MoveToStaffDown)
 				(d-StaffHidden hide))
 			(d-PopPosition)
 			(d-StaffHidden #f))))
