@@ -4,13 +4,11 @@
   (d-NewStructuredStaff)
   (d-SwapStaffs)
   (d-StaffProperties (string-append "denemo_name=" current "_ossia"))
-  (d-DirectivePut-score-prefix "HideEmptyStaffs" 
-                   "\\layout {
-                                     \\context { \\RemoveEmptyStaffContext }
-                                     }")
+   (if (not (d-Directive-layout? "HideEmptyStaffsAllSystems"))
+  	(d-HideEmptyStaffsAllSystems))
   (d-DirectivePut-staff-prefix tag "
     \\remove \"Time_signature_engraver\"
-    \\remove \"Key_engraver\"
+    \\hide Staff.KeySignature
       \\remove \"Clef_engraver\"
     fontSize = #-2
    \\override StaffSymbol #'staff-space = #(magstep -2)
