@@ -288,6 +288,7 @@ typedef GList measurenode;
  */
 typedef struct
 {
+  gchar *type; /**< type of staff, e.g. TabStaff or RhythmicStaff. Null for normal staffs */
   GtkMenu *staffmenu; /**< a menu to popup up with the staff directives attached */
   GtkMenu *voicemenu; /**< a menu to popup up with the voice directives attached */
   GList *sources;/**< List of source pixbufs, one for each measure staff-view */
@@ -328,6 +329,7 @@ typedef struct
   gint space_above; /**< space above the staff used in the denemo gui */
   gint space_shorten; /**< space by the staff is shorter in height because of few staff lines */
   gint space_below; /**< space below the staff used in the denemo gui */
+  gboolean fixed_height;/**< height of staff fixed by user - turn off auto-adjust*/
   gboolean range;/**<TRUE if range_hi,lo should be observed. */
   gint range_hi;/**< highest note playable by instrument, mid_c_offset */
   gint range_lo;/**< lowest note playable by instrument, mid_c_offset */
@@ -364,6 +366,8 @@ typedef struct DenemoMeasure {
     stemdirective *stemdir;
     gint measure_number; //measure number to display
     gint measure_numbering_offset;//measures from this one on should display numbers offset by this value from actual measure count.
+    gdouble earliest_time;//start time of measure, set by exportmidi if measure is empty
+    //gdouble latest_time;//end time of measure, set by exportmidi
 }  DenemoMeasure;
 
 /* The ->data part of each staffnode points to a staff structure */
@@ -460,6 +464,7 @@ typedef struct DenemoPrefs
   GString *profile; /**< Which set of commands and shortcuts to load, and which initialization of scheme to run */
   GString *lilypath; /**< This is the executable or full path to the lilypond executable */
   GString *graphicseditor; /**< editing eps graphics files */
+  GString *ghostscript; /**< for manipulating pdfs */
   GString *fontname; /**< Font name - usually Denemo as this has the required characters */
   gint fontsize; /**< Font size in points used for menus, help text etc */
   gboolean manualtypeset;/**< typeset on request, not continuously */
@@ -472,7 +477,7 @@ typedef struct DenemoPrefs
   gboolean immediateplayback; /**< This options sends audio directly to synth as notes are being entered */
   gint measureswitchsound; /**< MIDI key to play on cursor move to new measure */
   gint pitchspellingchannel; /**< channel to use for feedback when entering extreme intervals via MIDI in, that may indicate an enharmonic error, 0 means no pitch spelling*/
-  gint pitchspellingprogram; /**< program to set pitchspellingchannel to on startup */
+  gint use_pitchspelling; /**<whether or not to use pitchspelling on MIDI in */
   gboolean startmidiin; /**< try to start midi in on startup */
   gboolean notesonlymidiin; /**< whether to ignore MIDI signals other than note on/off from MIDI in source. */
   gboolean applytoselection; /**< apply commands to selection */
@@ -509,6 +514,7 @@ typedef struct DenemoPrefs
   gboolean saveparts; /**< Automatically save parts*/
   gboolean autosave; /**< whether to Auto save data */
   gint autosave_timeout;
+  gint recording_timeout;
   gboolean autoupdate;/**< update command set from denemo.org */
   gint maxhistory;/**< how long a history of used files to retain */
   gint compression;/**< compression to be applied to .denemo files, suffix is unchanged */
@@ -862,13 +868,15 @@ typedef enum DenemoRecordingType {
 
 typedef struct DenemoRecordedNote {
   gint timing;/**< time in frames, (divide by samplerate to get to seconds) */
-  gboolean noteoff;
+  //gboolean noteoff;
   gint mid_c_offset;
   gint enshift;
   gint octave;
   gint duration;/**< guessed baseduration, 0 if not known */
   gint dots; /**<guessed number of dots */
-  gpointer event;/**< midi event giving rise to the note */
+  gchar *midi_event;/* three byte midi message 0x90 or 0x80, midi_note*/
+  gint event_number;/**< GUIDED MIDI IMPORT ONLY number of midi event giving rise to the note */
+  gint track_number;/**< GUIDED MIDI IMPORT ONLY  track holding the event midi event giving rise to the note */
 } DenemoRecordedNote;
 
 typedef struct DenemoRecording {
@@ -876,11 +884,15 @@ typedef struct DenemoRecording {
   gchar *filename; /**< audio file. Could be extended to take MIDI file too */
   gint samplerate; /**< frames per second */
   gint channels; /**< audio only */
-  gint leadin;/**< number of frames to skip at start, silence to be emitted before play if negative */
+  gint leadin;/**< AUDIO: number of frames to skip at start, silence to be emitted before play if negative */
+  GList *sync;/**< Note onset that sync'd to measure */
+  gint marked_onset_position;/**< horizontal position in display of note onset in audio/midi marked by user */
+  GList *marked_onset;/**< Note onset in audio/recorded midi selected by user*/
   gdouble volume;
   gint nframes;/**< number of frames in the audio */
   GList *notes;  /**< data is DenemoRecordedNote* */
   gpointer sndfile; /**< sndfile handle */
+  gboolean click_track_created; /**<when creating click track do not clone measures and when adding to click track, call synchronize_recording() */
 } DenemoRecording;
 
 typedef enum DenemoTargetType {
@@ -915,10 +927,10 @@ typedef struct DenemoScrollPoint {
      gdouble time, adj;
      gdouble x, y;
 } DenemoScrollPoint;
-typedef struct DenemoOmissionCriterion {
+typedef struct DenemoInclusionCriterion {
      gchar *name;
      guint32 id;
-} DenemoOmissionCriterion;
+} DenemoInclusionCriterion;
 
 /*
  *  DenemoScore structure representing a single movement of a piece of music.
@@ -940,17 +952,16 @@ typedef struct DenemoMovement
   gint staffspace;
 
   DenemoRecording *recording;/**< Audio or MIDI recording attached to movement */
-  gint marked_onset_position;/**< horizontal position in display of note onset in audio marked by user */
-  GList *marked_onset;/**< Note onset in audio selected by user */
   gdouble start_time; /**< time in seconds to start playing at */
   gdouble end_time; /**< time to end playing at */
+  gboolean hovering_over_midi_track;/**< True when there is a midi track and the mouse is moving over it */
   DenemoObject *playingnow; /**< the last object played via MIDI; it must not be dereferenced as it may no longer exist */
   gdouble playhead; /**< MIDI time in seconds of playhead, ie point when last MIDI event was processed for output */
   gdouble start_player;/**< system time when MIDI player started */
-  gpointer recorded_midi_track;//will be a GList * eventually for now an smf_track_t
+  gpointer recorded_midi_track;//an smf_track_t recorded
+  gpointer loaded_midi_track;//a (part of) the recorded_midi_track synchronized to the score
+  
   gdouble master_volume;/**< the volume (velocity) used is this times the nominal vol */
-  gdouble master_tempo;/**< the tempo used is this times the nominal tempo */
-  gdouble tempo_change_time;/**< system time from which the master_tempo is to be used */
   gdouble rightmost_time; /**< MIDI time of rightmost visible object */
   GList *scroll_points; /**< playback view scroll points for this movement */
   DenemoDirective* directive_on_clipboard;/**< when a (non-standalone) directive can be "pasted" using the script CreateScriptForDirective::clipboard this records its origin. Do not de-reference as it may no longer exist */
@@ -1076,7 +1087,9 @@ typedef struct DenemoProject
   InputSource last_source;/**< Where the last input came from */
   MidiDestination midi_destination;/**< Where MIDI in should go */
   GQueue *pending_midi;/**< a MIDI effect to be output with the next note */
-  gboolean audio_recording;
+  gboolean audio_recording; // currently recording audio output
+  gboolean midi_recording; // currently recording MIDI input
+  gboolean midi_capture_on; //MIDI in signals are currently being intercepted by user's script
   input_mode mode; /**< Input mode for Score */
 
 
@@ -1092,8 +1105,8 @@ typedef struct DenemoProject
   GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
   GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
   guint layout_id; /**< cached value of the currently selected layout id */
-  DenemoOmissionCriterion *criterion; /**< an omission criterion chosen by the user to avoid directives marked to ignore this name - a lightweight score layout in effect. */
-  GList *criteria; /**< a list of DenemoOmissionCriterion which have been defined for this score */
+  DenemoInclusionCriterion *criterion; /**< an inclusion criterion chosen by the user to avoid directives marked to ignore this name - a lightweight score layout in effect. */
+  GList *criteria; /**< a list of DenemoInclusionCriterion which have been defined for this score */
   GList *callbacks;/**< scheme callbacks on deletion */
   gpointer lilystart, lilyend; /**<range of lilytext  */
   GString **target; /**< pointer to target string for modification in lilytext  */
@@ -1217,15 +1230,19 @@ struct DenemoRoot
   gboolean hovering_over_movement;
   gboolean hovering_over_left_arrow;
   gboolean hovering_over_right_arrow;
+  gint right_arrow_x;
   GList *object_hovering_over;
   gboolean dragging_start_playback_marker;
   gboolean dragging_end_playback_marker;
+  gint playback_marker_brightness;
   
   GdkCursor *GDK_LEFT_PTR;
   GdkCursor *GDK_SB_V_DOUBLE_ARROW;
   GdkCursor *GDK_SB_H_DOUBLE_ARROW;
+  GdkCursor *GDK_BLANK_CURSOR;
   GdkCursor *GDK_X_CURSOR;
   GdkCursor *GDK_TARGET;
+  GdkCursor *GDK_CIRCLE;
   
   
   
@@ -1246,7 +1263,6 @@ struct DenemoRoot
   GtkWidget *statuslabel;/**< label that appears at bottom left of main window to describe cursor position in score */
   GtkWidget *playback_control;/**< frame containing controls for playback */
   GtkWidget *midi_in_control;/**< frame containing controls for midi in */
-  GtkWidget *audio_vol_control;/**< hbox containing vol control for source audio */
   GtkWidget *input_label; /**< A label widget advising of source of external input */
   GString *input_filters; /**< Description of any filters operating on external input */
   GtkWidget *menubar;/**< Main menubar to giving load/save play etc functionality */
