@@ -13,6 +13,7 @@
 
 #include <denemo/denemo.h>
 #include "audio/midi.h"
+#include "audio/midirecord.h"
 #include "audio/audiointerface.h"
 #include "smf.h"
 #include "export/exportmidi.h"
@@ -27,6 +28,7 @@
 #include <string.h>
 #include <assert.h>
 
+
 #define SHAVING (0.01)          //seconds to shave off a note start time to ensure stopping before noteon is sent, and starting with noteon first note may depend of speed of machine??? FIXME
 
 
@@ -35,8 +37,8 @@ static volatile gboolean playing = FALSE;
 
 static double last_draw_time;
 
-// huh?
-static gboolean midi_capture_on = FALSE;        //any midi events not caught by midi_divert will be dropped if this is true
+ //any midi events not caught by midi_divert will be dropped if this is true
+#define midi_capture_on Denemo.project->midi_capture_on
 
 static gdouble play_until = G_MAXDOUBLE;
 
@@ -92,31 +94,14 @@ update_position (smf_event_t * event)
     }
 }
 
-static void
-safely_add_track (smf_t * smf, smf_track_t * track)
-{
-    track->smf = NULL;
-    smf_add_track (smf, track);
-}
-
-static void
-safely_track_remove_from_smf (smf_track_t * track)
-{
-  if (track->smf != NULL && (track->track_number>=1))
-    smf_track_remove_from_smf (track);
-  track->smf = NULL;
-}
 
 static GString *callback_script = NULL;
-void
-start_playing (gchar * callback)
+void start_playing (gchar * callback)
 {
   smf_t *smf = Denemo.project->movement->smf;
   if (callback && *callback)
     callback_script = g_string_new (callback);
-  if (Denemo.project->movement->recorded_midi_track)
-    safely_add_track (Denemo.project->movement->smf, Denemo.project->movement->recorded_midi_track);
-
+ 
   fix_start_end_ordering ();
   smf_rewind (smf);
   gdouble start = (Denemo.project->movement->start_time/get_playback_speed()) - SHAVING;
@@ -131,49 +116,33 @@ start_playing (gchar * callback)
   last_draw_time = -1.0;//needed to trigger drawing first note
 }
 
-static gboolean
-stop_play_callback (gchar * thescript)
+static gboolean stop_play_callback (gchar * thescript)
 {
   call_out_to_guile (thescript);
   g_free (thescript);
   return FALSE;
 }
 
-static gboolean do_set_playbutton (gboolean paused)
+static gboolean do_set_playbutton ()
 {
-    set_playbutton (paused);
+    set_playbutton ();
     return FALSE;
 }
-static gboolean
-update_playbutton_callback (gboolean paused)
+static gboolean update_playbutton_callback (void)
 {
-
-  g_main_context_invoke (NULL, (GSourceFunc)do_set_playbutton, GINT_TO_POINTER(paused));
-
+  g_main_context_invoke (NULL, (GSourceFunc)do_set_playbutton, NULL);
   return FALSE;
 }
 
-static void
-finish_recording (void)
-{
-  if ((Denemo.project->midi_destination & MIDIRECORD))
-    {
-      Denemo.project->midi_destination ^= MIDIRECORD;
-      g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) show_midi_record_control, NULL, NULL);
-    }
-}
+
 void
-stop_playing ()
+stop_playing (void)
 {
   update_position (NULL);
-  g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) update_playbutton_callback, GINT_TO_POINTER (is_paused ()), NULL);
+  g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) update_playbutton_callback, NULL, NULL);
   playing = FALSE;
-  play_until = -G_MAXDOUBLE;
-  if (Denemo.project->movement && Denemo.project->movement->recorded_midi_track)
-    {
-      safely_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
-      finish_recording ();
-    }
+  play_until = 0.0;
+	//play_until = -G_MAXDOUBLE;
   if (callback_script)
     {
       g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) stop_play_callback, g_string_free (callback_script, FALSE), NULL);
@@ -182,7 +151,7 @@ stop_playing ()
 }
 
 void
-toggle_paused ()
+toggle_paused (void)
 {
   if (play_until < 0.0)
     play_until = G_MAXDOUBLE;
@@ -234,16 +203,16 @@ get_start_time ()
 double
 get_end_time ()
 {
-  if (Denemo.project && Denemo.project->movement && Denemo.project->movement->smf)
+  if (Denemo.project && Denemo.project->movement && (Denemo.project->movement->end_time > 0.0))
     {
-      if (Denemo.project->movement->end_time < 0.0)
-        Denemo.project->movement->end_time = smf_get_length_seconds (Denemo.project->movement->smf);
-      return Denemo.project->movement->end_time;
+      return  Denemo.project->movement->end_time;
     }
   else
     {
-      return 0.0;
+	 // if (Denemo.project->movement->smf) smf_get_length_seconds (Denemo.project->movement->smf); seems not to be thread safe ...
+		return 0.0;
     }
+ return 0.0;
 }
 
 
@@ -287,13 +256,7 @@ get_smf_event (double until_time)
 gdouble
 get_time ()
 {
-  GTimeVal tv;
-  double seconds;
-
-  g_get_current_time (&tv);
-
-  seconds = tv.tv_sec + tv.tv_usec / 1000000.0;
-  return seconds;
+  return g_get_real_time () / 1000000.0;
 }
 
 
@@ -421,54 +384,24 @@ typedef struct enharmonic
 } enharmonic;
 
 
-void new_midi_recording (void) {
-  DenemoRecording *recording;
-  if(Denemo.project->movement->recording && (Denemo.project->movement->recording->type==DENEMO_RECORDING_MIDI))
-    {
-      //FIXME a better name for the mutex which originally was just for midi data, but will work for audio data too.
-      recording = Denemo.project->movement->recording;
-      g_mutex_lock (&smfmutex);
-      Denemo.project->movement->recording = NULL;
-      g_mutex_unlock (&smfmutex);
-      g_free (recording->filename);
-      g_free (recording);
-      g_list_free_full (recording->notes, g_free);
-     }
-  recording = (DenemoRecording *) g_malloc (sizeof (DenemoRecording));
-  recording->type = DENEMO_RECORDING_MIDI;
-  recording->samplerate = 44100;
-  Denemo.project->movement->recording = recording;
-}
-
-//Add the passed midi to a recording in Denemo.project->movement
-static void
-record_midi (gchar * buf, gdouble time)
+gdouble get_time_at_cursor (void)
 {
-  buf[0] |= 0xF; //here force the channel to 15
-  smf_event_t *event = smf_event_new_from_pointer (buf, 3);
-  if (event && smf_event_is_valid (event))
-    {
-      if (Denemo.project->movement->recorded_midi_track && ((smf_track_t *) Denemo.project->movement->recorded_midi_track)->smf)
-        {
-
-          smf_track_add_event_seconds (Denemo.project->movement->recorded_midi_track, event, time);
-          if(Denemo.project->movement->recording && noteon_key(event))
-            {
-                DenemoRecordedNote *note = g_malloc0(sizeof(DenemoRecordedNote));
-                note->timing = event->time_seconds * Denemo.project->movement->recording->samplerate;
-                notenum2enharmonic (noteon_key(event), &(note->mid_c_offset), &(note->enshift), &(note->octave));
-                note->event = event;
-                Denemo.project->movement->recording->notes = g_list_append (Denemo.project->movement->recording->notes, note);
-            }
-        }
-      else
-        {
-          smf_event_delete (event);
-          gdk_beep ();
-        }
-    }
+	GList *curobj = Denemo.project->movement->currentobject;
+	gdouble time = 0.0;
+	DenemoObject *obj;
+	if (curobj)
+		{
+			obj = Denemo.project->movement->currentobject->data; 
+			time = Denemo.project->movement->cursor_appending ? obj->latest_time :  obj->earliest_time;	//g_print ("Get time at cursor: Object %p time at cursor %f\n", obj, time);
+		}
+	else
+		time = ((DenemoMeasure*)Denemo.project->movement->currentmeasure->data)->earliest_time;
+	//g_print ("Get time at cursor:so time at cursor %f\n", time);
+	return time;
 }
 
+
+
 static void
 do_one_note (gint mid_c_offset, gint enshift, gint notenum)
 {//g_print("do one note Adding mask %x, Chord mask %x\n", (Denemo.keyboard_state & ADDING_MASK) , (Denemo.keyboard_state & CHORD_MASK));
@@ -589,6 +522,10 @@ midiaction (gint notenum)
   enharmonic enote, prevenote;
   gboolean have_previous;
   //g_print("midiaction Adding mask %x, Chord mask %x\n", (Denemo.keyboard_state & ADDING_MASK) , (Denemo.keyboard_state & CHORD_MASK));
+  GList *marked_onset = gui->movement->recording?gui->movement->recording->marked_onset:NULL;
+  if (gui->movement->recording)
+	gui->movement->recording->marked_onset = NULL;//this prevents playing on the MIDI keyboard triggering taking note pitches from MIDI recording at marked_onset
+  
   notenum2enharmonic (notenum, &enote.mid_c_offset, &enote.enshift, &enote.octave);
   if (Denemo.project->movement->cursor_appending)
     have_previous = get_current (&prevenote);
@@ -700,7 +637,7 @@ midiaction (gint notenum)
             signal_measure_end();
         }
     }
-
+  if (gui->movement->recording) gui->movement->recording->marked_onset = marked_onset;
   return TRUE;
 }
 
@@ -716,6 +653,7 @@ set_midi_capture (gboolean set)
 }
 
 
+
 #define command ((*buf)&0xF0)
 #define notenumber ((*(buf+1))&0x7F)
 #define velocity ((*(buf+2))&0x7F)
@@ -728,7 +666,7 @@ adjust_midi_velocity (gchar * buf, gint percent)
 
 void add_after_touch (gchar * buf)
 {
-   if (Denemo.prefs.damping)
+   if (Denemo.prefs.damping && (((DenemoStaff *) Denemo.project->movement->currentstaff->data)->override_volume || (Denemo.prefs.dynamic_compression == 100)))
     {
       static gdouble times[0x7F]; //takes no account of channel, really only good for one channel.
       //HACK IN kill pitch bend and "modulation" wheel here
@@ -927,9 +865,12 @@ adjust_to_staff (gchar * buf)
 void
 play_adjusted_midi_event (gchar * buf)
 {
+  gboolean was_note_on = ((buf[0] & SYS_EXCLUSIVE_MESSAGE1) == MIDI_NOTE_ON);
   adjust_midi_velocity (buf, 100 - Denemo.prefs.dynamic_compression);
   add_after_touch (buf);
   adjust_to_staff (buf);
+  if (was_note_on && ((DenemoStaff *) Denemo.project->movement->currentstaff->data)->override_volume)
+		buf[2]=127;
   //g_print ("play adj midibytes 0x%hhX 0x%hhX 0x%hhX\n", *(buf+0), *(buf+1), *(buf+2));
   play_midi_event (DEFAULT_BACKEND, 0, (guchar*) buf);
 }
@@ -962,16 +903,42 @@ handle_midi_event (gchar * buf)
     }
   if ((Denemo.project->midi_destination & MIDIRECORD) || (Denemo.project->midi_destination & (MIDIPLAYALONG | MIDICONDUCT)))
     {
+	  
       if (Denemo.project->midi_destination & MIDIRECORD)
-        record_midi (buf, get_playback_time ());
+        record_midi (buf);
       if (Denemo.project->midi_destination & (MIDIPLAYALONG))
         advance_until_time (buf);//FIXME is this thread-safe????
       else
-        play_adjusted_midi_event (buf);//play_midi_event (DEFAULT_BACKEND, 0, (guchar *) buf);
+       {
+		   GList *g;
+		   if (Denemo.project->movement->recording && (g = g_list_last (Denemo.project->movement->recording->notes)))
+			{
+				DenemoRecordedNote *note, *prevnote;
+				note = (DenemoRecordedNote *)g->data;
+				prevnote = g->prev?(DenemoRecordedNote *)g->prev->data : NULL;
+				if (Denemo.prefs.use_pitchspelling && note && prevnote && check_interval (note->mid_c_offset, note->enshift, prevnote->mid_c_offset, prevnote->enshift))
+					{
+						gint channel = Denemo.prefs.pitchspellingchannel;
+						buf[0] = (buf[0] & 0xF0) | channel;
+						//g_print ("Now %x from midcoffset %d enshift %d to %d %d\n", buf[0], note->mid_c_offset, note->enshift, prevnote->mid_c_offset, prevnote->enshift);
+						play_note (DEFAULT_BACKEND, 0 /*port */ , channel, buf[1], 300 /*duration */ , 0);
+						//play_midi_event (DEFAULT_BACKEND, 0, (guchar*) buf); //audiointerface.h puts buf[] into the immediate queue, however we can't catch the note off which would be in the wrong channel
+					}
+				else
+					play_adjusted_midi_event (buf);
+			}
+		else		
+		   play_adjusted_midi_event (buf);//play_midi_event (DEFAULT_BACKEND, 0, (guchar *) buf);
+		}
     }
   else
     {
-      if ((Denemo.keyboard_state == (GDK_SHIFT_MASK | GDK_LOCK_MASK)) || Denemo.keyboard_state == (GDK_CONTROL_MASK) || Denemo.keyboard_state == (ADDING_MASK) || Denemo.keyboard_state == ((ADDING_MASK) | (CHORD_MASK)) || Denemo.keyboard_state == (GDK_CONTROL_MASK | GDK_LOCK_MASK) || (Denemo.keyboard_state == 0))
+      if ((Denemo.keyboard_state == (GDK_SHIFT_MASK | GDK_LOCK_MASK)) ||
+           Denemo.keyboard_state == (GDK_CONTROL_MASK) ||
+           Denemo.keyboard_state == (ADDING_MASK) ||
+           Denemo.keyboard_state == ((ADDING_MASK) | (CHORD_MASK)) ||
+           Denemo.keyboard_state == (GDK_CONTROL_MASK | GDK_LOCK_MASK) ||
+           Denemo.keyboard_state == 0)
         process_midi_event (buf);
       else if (Denemo.keyboard_state == (GDK_SHIFT_MASK) || Denemo.keyboard_state == (GDK_LOCK_MASK))
         {
