@@ -20,6 +20,7 @@
 #include "audio/midi.h"
 #include "core/view.h"
 #include "source/sourceaudio.h"
+#include "audio/fluid.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -34,20 +35,6 @@
 #endif
 #include <errno.h>
 
-void
-set_tempo (void)
-{
-  gdouble tempo = Denemo.project->movement->master_tempo;
-  if (tempo < 0.001 || (tempo > 0.999 && tempo < 1.001))
-    return;
-  Denemo.project->movement->tempo *= tempo;
-  Denemo.project->movement->start_time /= tempo;
-  Denemo.project->movement->end_time /= tempo;
-
-  Denemo.project->movement->master_tempo = 1.0;
-  //caller should call this:score_status (Denemo.project, TRUE);
-  // caller should call this: exportmidi (NULL, Denemo.project->movement);
-}
 
 
 /* start playing the current movement as MIDI
@@ -61,13 +48,13 @@ ext_midi_playback (DenemoAction * action, DenemoScriptParam * param)
 
   GET_1PARAM (action, param, callback);
 
-  set_playbutton (is_paused ());
+  set_playbutton ();
   if (is_playing ())
     {
       toggle_paused ();
+      fluidsynth_all_notes_off ();
       return;
     }
-  set_tempo ();
 #ifdef DISABLE_AUBIO
 #else
   //rewind_audio(); done in start_audio_playing()
@@ -88,19 +75,15 @@ restart_play (void)
 void
 stop_midi_playback (DenemoAction * action, DenemoScriptParam* param)
 {
-
-  if (is_paused ())
-    toggle_paused ();
-  else
-    set_playbutton (TRUE);
   midi_stop ();
   if (Denemo.playbackview)
     gtk_widget_queue_draw (Denemo.playbackview);
+  set_playbutton ();    
   draw_score_area();     //update playhead on screen
 }
 
 void
-playback_panic ()
+playback_panic (void)
 {
   panic_all ();
 }
