@@ -12,6 +12,8 @@
 #include "command/commandfuncs.h"
 #include "core/kbd-custom.h"
 #include "audio/audiointerface.h"
+#include "audio/midirecord.h"
+
 #if GTK_MAJOR_VERSION==3
 #include <gdk/gdkkeysyms-compat.h>      //FIXME Look for something more gtk3 like
 #endif
@@ -125,6 +127,7 @@ llock_mask (gint keyval)
 gint
 scorearea_keyrelease_event (GtkWidget * widget, GdkEventKey * event)
 {
+	//g_print ("Scorearea key release event: keyval %d (%s), string |%s|, length %d, state %x, keycode %d, group %d, is_modifier flag %d\n", event->keyval, gdk_keyval_name(event->keyval), event->string, event->length, event->state, event->hardware_keycode, event->group, event->is_modifier);
      if(!Denemo.keyboard_state_locked)
           {
               Denemo.keyboard_state ^= (0xf & klock_mask (event->keyval));
@@ -133,10 +136,39 @@ scorearea_keyrelease_event (GtkWidget * widget, GdkEventKey * event)
                   if ((Denemo.keyboard_state & CHORD_MASK)) //At least one note has been entered in a chord
                     next_editable_note ();
                   Denemo.keyboard_state &= ~CHORD_MASK;
+                  set_midi_in_status ();
                 }
-              set_midi_in_status ();
+               else if ((Denemo.keyboard_state == 0) && ((event->keyval == GDK_Shift_L) || (event->keyval == GDK_Shift_R)))
+				{
+				if (Denemo.project->movement->recording && (Denemo.project->movement->recording->type == DENEMO_RECORDING_MIDI))
+					toggle_midi_record ();
+				set_midi_in_status ();	
+				}
+			  else if ((Denemo.keyboard_state == 0) && ((event->keyval == GDK_Control_L) || (event->keyval == GDK_Control_R)))
+				{
+				 if (Denemo.project->movement->recording && (Denemo.project->movement->recording->type == DENEMO_RECORDING_MIDI))
+					toggle_midi_record ();
+				set_midi_in_status ();	
+				}
+              
         }
-  //g_print("release %x state %x\n", Denemo.keyboard_state, event->state);
+     else
+		{
+			if ((Denemo.keyboard_state == 0) && ((event->keyval == GDK_Shift_L) || (event->keyval == GDK_Shift_R)))
+					{
+
+						Denemo.keyboard_state = 1;
+						set_midi_in_status ();
+					}
+			else
+				if ((Denemo.keyboard_state == 0) && ((event->keyval == GDK_Control_L) || (event->keyval == GDK_Control_R)))
+						{
+														
+							Denemo.keyboard_state = 4;
+							set_midi_in_status ();
+						}
+		}
+  //g_print("release Denemo keyboard state %x keyboard+state_locked %x from event state %x\n", Denemo.keyboard_state, Denemo.keyboard_state_locked, event->state);
   // set_cursor_for(keyrelease_modify(event->state), event->keyval);
   gint state;
   if ((event->keyval == GDK_Caps_Lock) || (event->keyval == GDK_Num_Lock))
@@ -161,8 +193,11 @@ perform_command (const gchar * command_name, GdkEventKey * event)
   if (Denemo.project->movement)
     displayhelper (Denemo.project);
 #endif
-  g_string_printf (Denemo.input_filters, "%s  <span foreground=\"Green\">%s.</span> <span foreground=\"blue\">%s</span>", command_name, _("Help"), _("(use Fn12 to Repeat)"));
+  gchar *trunc = g_strdup (lookup_label_from_idx (Denemo.map, Denemo.LastCommandId));  
+  truncate_label (NULL, trunc);
+  g_string_printf (Denemo.input_filters, "%s  <span foreground=\"Green\">%s.</span> <span foreground=\"blue\">%s</span>", trunc, _("Help"), _("(use Fn12 to Repeat)"));
   write_input_status();
+  g_free (trunc);
   return NULL;
 }
 
@@ -251,14 +286,16 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
         {                       //Two key name was not a binding
           ret = NULL;
           write_status (Denemo.project);
-          if ((Denemo.project->view != DENEMO_MENU_VIEW) || Denemo.prefs.learning)
+          if (Denemo.prefs.learning)
             {
-                            Denemo.prefs.learning = TRUE;
               KeyStrokeDecline (prefix_store->str);
-            }
-          toggle_to_drawing_area (TRUE);        //restore menus, in case the user is lost and needs to look up a keypress
-          if (Denemo.project->view != DENEMO_MENU_VIEW)
+               //restore menus, in case the user is lost and needs to look up a keypress
+			  if (Denemo.project->view != DENEMO_MENU_VIEW)
                         toggle_to_drawing_area (TRUE);
+              if (Denemo.project->view != DENEMO_MENU_VIEW)
+                        toggle_to_drawing_area (TRUE);
+            }
+        
 
         }
       g_string_assign (prefix_store, "");
@@ -275,7 +312,7 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
           GString *continuations = g_string_new ("");
           for (g = Denemo.continuations; g; g = g->next)
             g_string_append_printf (continuations, "%s%s", (gchar *) g->data, _(", or "));
-          g_string_printf (prefix_store, _( "Prefix Key %s, waiting for key %stype Esc to abort"), name, continuations->str);
+          g_string_printf (prefix_store, _( "Prefix Key %s, waiting for key %sother to abort"), name, continuations->str);
           g_string_free (continuations, TRUE);
           if (Denemo.prefs.immediateplayback)
               play_note (DEFAULT_BACKEND, 0, 9, 61, 300, 127 * Denemo.project->movement->master_volume);
@@ -290,18 +327,17 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
         }
       else
         {
-          if ((Denemo.project->view != DENEMO_MENU_VIEW) || Denemo.prefs.learning)
-            {
-              Denemo.prefs.learning = TRUE;
+          if (Denemo.prefs.learning)
               KeyStrokeDecline (name);
-            }
-          toggle_to_drawing_area (TRUE);  //restore menus, in case the user is lost and needs to look up a keypress
-          if (Denemo.project->view != DENEMO_MENU_VIEW)
-              toggle_to_drawing_area (TRUE);
-          if (repeated_key)
+          else if (repeated_key)
              {
                Denemo.prefs.learning = TRUE;
                KeyStrokeShow (name, command_idx, TRUE);
+               //restore menus, in case the user is lost and needs to look up a keypress
+			   if (Denemo.project->view != DENEMO_MENU_VIEW)
+				   toggle_to_drawing_area (TRUE);
+			   if (Denemo.project->view != DENEMO_MENU_VIEW)
+				   toggle_to_drawing_area (TRUE);
              }
         }
       return NULL;
@@ -332,12 +368,33 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
 
       if(!Denemo.keyboard_state_locked)
           {
+			  //g_print ("keyboard state not locked state is %x\t", Denemo.keyboard_state);
               Denemo.keyboard_state |= (0xf & klock_mask (event->keyval));
               Denemo.keyboard_state ^= llock_mask (event->keyval);
-              // if((event->keyval==GDK_Alt_L)||(event->keyval==GDK_Alt_R))
-              //  Denemo.keyboard_state |= CHORD_MASK;
+              //g_print ("...becomes %x\t", Denemo.keyboard_state);
+            if (Denemo.project->movement->recording && (Denemo.project->midi_destination & MIDIRECORD) && 
+					(Denemo.keyboard_state == 1) && ((event->keyval == GDK_Shift_L) || (event->keyval == GDK_Shift_R)))
+				toggle_midi_record ();	
               set_midi_in_status ();
+              //g_print ("...leaving %x, locked is now %x\n", Denemo.keyboard_state, Denemo.keyboard_state_locked);
           }
+       else
+		{
+			//g_print ("keyboard state is locked, state is %x\n", Denemo.keyboard_state);
+			//g_print ("Scorearea key press event: keyval %d (%s), string |%s|, length %d, state %x, keycode %d, group %d, is_modifier flag %d\n", event->keyval, gdk_keyval_name(event->keyval), event->string, event->length, event->state, event->hardware_keycode, event->group, event->is_modifier);
+			if ((Denemo.keyboard_state == 1) && ((event->keyval == GDK_Shift_L) || (event->keyval == GDK_Shift_R)))
+				{
+					Denemo.keyboard_state = 0;
+					set_midi_in_status ();
+				}
+			 else
+				if ((Denemo.keyboard_state == 4) && ((event->keyval == GDK_Control_L) || (event->keyval == GDK_Control_R)))
+						{
+							Denemo.keyboard_state = 0;
+							set_midi_in_status ();
+						}
+
+		}
   //g_print("press Denemo %x state %x klock %x\n", Denemo.keyboard_state, event->state, klock_mask(event->keyval));
 
   //g_debug("State eored %x\n", (lock_mask(event->keyval)^event->state));
@@ -355,39 +412,39 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
 }
 
 /**
- * Reduce the measure width by 10 pixels
+ * Reduce the measure width by 2 pixels
  */
 void
 adjust_measure_less_width_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  adjustmeasurewidth (Denemo.project->movement, -10);
+  adjustmeasurewidth (Denemo.project->movement, -2);
 }
 
 /**
- * Enlarge the measure width by 10 pixels
+ * Enlarge the measure width by 2 pixels
  */
 void
 adjust_measure_more_width_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  adjustmeasurewidth (Denemo.project->movement, 10);
+  adjustmeasurewidth (Denemo.project->movement, 2);
 }
 
 /**
- * Reduce the staff height by 10 pixels
+ * Reduce the staff height by 2 pixels
  */
 void
 adjust_staff_less_height_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  adjuststaffheight (Denemo.project->movement, -10);
+  adjuststaffheight (Denemo.project->movement, -2);
 }
 
 /**
- * Enlarge the staff height by 10 pixels
+ * Enlarge the staff height by 2 pixels
  */
 void
 adjust_staff_more_height_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  adjuststaffheight (Denemo.project->movement, 10);
+  adjuststaffheight (Denemo.project->movement, 2);
 
 }
 
@@ -521,14 +578,18 @@ octave_shift_key (DenemoScriptParam *param, gint amount)
                   Denemo.project->movement->undo_guard++;
                   delete_chordnote (Denemo.project);       //does not delete the directives.
                   Denemo.project->movement->cursor_y = copy.mid_c_offset + amount;
+                  Denemo.project->movement->staffletter_y  = offsettonumber (Denemo.project->movement->cursor_y);
+                 // turn off  Denemo.prefs.immediateplayback as it plays the note with potentially the wrong enshift
+                  gboolean old = Denemo.prefs.immediateplayback;
+                  Denemo.prefs.immediateplayback = FALSE;
                   insert_chordnote (Denemo.project);
                   changeenshift (Denemo.project->movement->currentobject->data, Denemo.project->movement->cursor_y, copy.enshift);
                   thenote = nearestnote (Denemo.project->movement->currentobject->data, Denemo.project->movement->cursor_y);
                   if (thenote)
                     ((note *) thenote->data)->directives = direcs;
-                    
-                  Denemo.project->movement->staffletter_y  = offsettonumber (Denemo.project->movement->cursor_y);
-                    
+                  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
+                  play_notes (DEFAULT_BACKEND, curstaffstruct->midi_port, curstaffstruct->midi_channel, (chord *) ((DenemoObject*)Denemo.project->movement->currentobject->data)->object); 
+                  Denemo.prefs.immediateplayback = old;
                   Denemo.project->movement->undo_guard--;
                   score_status (Denemo.project, TRUE);
                 }
@@ -607,6 +668,8 @@ insert_measure_key (DenemoAction* action, DenemoScriptParam *param)
 static void
 insert_chord_xdur (gint duration, DenemoScriptParam *param)
 {
+  if (Denemo.project->movement->recording && (Denemo.project->movement->recording->type == DENEMO_RECORDING_MIDI) && Denemo.project->movement->recording->marked_onset)
+	Denemo.project->last_source = INPUTKEYBOARD;
   dnm_insertnote (Denemo.project, duration, Denemo.project->mode, FALSE);//gets it wrong
   displayhelper (Denemo.project);
   score_status(Denemo.project, TRUE);
@@ -834,8 +897,10 @@ deletepreviousobject (DenemoAction* action, DenemoScriptParam *param)
                 RhythmPattern *cursnip = (RhythmPattern *)Denemo.project->currhythm->data;
                 set_rhythm_label (cursnip, ((RhythmElement *) Denemo.project->rstep->data)->highlightlabel);
             }
-        }
+        } 
 
+	  if (Denemo.project->movement->recording && (Denemo.project->movement->recording->type == DENEMO_RECORDING_MIDI) && anote && Denemo.project->movement->recording->marked_onset)
+		  advance_marked_midi (-1);
     }
   else
     {                           /* go to the previous measure, go to end of it, and start deleting there */
