@@ -84,7 +84,7 @@
 {"AppendMeasure", NULL, N_("Staff Append Measure"), "",N_("Append an empty measure at the end of the current staff"),G_CALLBACK (append_measure_key)},
 {"DeleteMeasure", NULL, N_("Staff Delete Measure"), "",N_("Delete the current measure in this staff, leaving the staff short"),G_CALLBACK (deletemeasure)},
 {"DeleteMeasureAllStaffs", NULL, N_("Delete Measure All Staffs"), "",N_("Delete the current measure in all staffs"),G_CALLBACK (deletemeasureallstaffs)},
-{"ShrinkMeasures", NULL, N_("Shrink Measure"), "",N_("No Tooltip yet"),G_CALLBACK (adjust_measure_less_width_key)},
+{"ShrinkMeasures", NULL, N_("Shrink Measures"), "",N_("No Tooltip yet"),G_CALLBACK (adjust_measure_less_width_key)},
 {"WidenMeasures", NULL, N_("Widen Measures"), "",N_("No Tooltip yet"),G_CALLBACK (adjust_measure_more_width_key)},
 {"ShorterStaffs", NULL, N_("Shorter Staffs"), "",N_("No Tooltip yet"),G_CALLBACK (adjust_staff_less_height_key)},
 {"TallerStaffs", NULL, N_("Taller Staffs"), "",N_("No Tooltip yet"),G_CALLBACK (adjust_staff_more_height_key)},
@@ -214,7 +214,7 @@
 {"InputMenu", NULL, N_("Input"), "",N_("Menu:\nChoose whether to get input audio (e.g. microphone) or MIDI controller (e.g. MIDI keyboard)\nor just from the pc keyboard.")},
 {"SharpenEnharmonicSet", NULL, N_("Shift Accidentals Sharpwise"), "",N_("Shifts the set of accidentals one step sharper"),G_CALLBACK (set_sharper)},
 {"FlattenEnharmonicSet", NULL, N_("Shift Accidentals Flatwise"), "",N_("Shifts the set of accidentals one step flatter"),G_CALLBACK (set_flatter)},
-{"PlaybackMenu", NULL, N_("Playback"), "",N_("Music playback. Music is played between the playback start (green bar) and playback end (red bar).\nThere are playback controls (See View->Playback Controls) which make it easy to set and re-set these and also to loop-play, choose the temperament to play in etc. Or use items in this menu to play the whole piece from the cursor to the end.")},
+{"PlaybackMenu", NULL, N_("Playback/Record"), "",N_("Music playback and recording. Music is played between the playback start (green bar) and playback end (red bar).\nThere are playback controls (See View->Playback Controls) which make it easy to set and re-set these and also to loop-play, choose the temperament to play in etc. Or use items in this menu to play the whole piece from the cursor to the end.")},
 {"New", GTK_STOCK_NEW, N_("Empty Score"), "",N_("Start a new musical score"),G_CALLBACK (file_newwrapper)},
 {"NewScore", GTK_STOCK_NEW, N_("New"), "",N_("Start a new musical score for a named instrument/voice."),G_CALLBACK (new_score_cb)},
 {"OpenMenu", GTK_STOCK_OPEN, N_("Open"), "",N_("Menu:\nOpen a previously edited score, or a source file for transcription")},
@@ -243,14 +243,14 @@
 {"ExportMusicXML", GTK_STOCK_SAVE_AS, N_("Export MusicXML"), "",N_("Export the score as a MusicXML file"),G_CALLBACK (export_musicxml_action)},
 {"ExportPDF", GTK_STOCK_SAVE_AS, N_("Export PDF"), "",N_("Export the score as a PDF document file"),G_CALLBACK (export_pdf_action)},
 {"ExportPNG", GTK_STOCK_SAVE_AS, N_("Export Score as PNG"), "",N_("Export the score as a PNG image file"),G_CALLBACK (export_png_action)},
-{"ExportMIDI", GTK_STOCK_SAVE_AS, N_("Export MIDI"), "",N_("Export the score as a MIDI file"),G_CALLBACK (export_midi_action)},
+{"ExportMIDI", GTK_STOCK_SAVE_AS, N_("Export MIDI"), "",N_("Export the current score as a MIDI file"),G_CALLBACK (export_midi_action)},
 {"PrintMenu", GTK_STOCK_PRINT, N_("Print"), "",N_("Menu:\nCommands for typesetting and then printing the music.\nA part, movement, full score or various reduced scores can be typeset.\n See also the Score Layout view for further options.")},
 {"PrintView", GTK_STOCK_PRINT_PREVIEW, N_("Print Preview"), "",N_("Typesets the score\nIf you have a score layout selected it will use that\notherwise all movements staffs and lyrics are typeset by default.\nBe patient! It takes time to create a beautifully laid out score.\nOnce complete you can view and then send to your printer or to a file as a .pdf document."),G_CALLBACK (show_print_view)},
 {"PrintSelection", GTK_STOCK_PRINT, N_("Print Selection"), "",N_("Displays selected music from score in your pdf viewer"),G_CALLBACK (printselection_cb)},
 {"PrintExcerptPreview", GTK_STOCK_PRINT_PREVIEW, N_("Export Selection as PNG"), "",N_("Displays a musical excerpt in your image viewer"),G_CALLBACK (printexcerptpreview_cb)},
 {"PrintMovement", GTK_STOCK_PRINT, N_("Print Movement"), "",N_("Typesets the current movement and opens a print dialog"),G_CALLBACK (printmovement_cb)},
 {"Print", GTK_STOCK_PRINT, N_("Print"), "",N_("Typesets the score using LilyPond and opens a print dialog"),G_CALLBACK (printall_cb)},
-{"PrintHistory", NULL, N_("Print History"), "",N_("Shows the history of print outs for this score. Only saved documents have their printing recorded"),G_CALLBACK (display_printhistory)},
+{"PrintHistory", NULL, N_("History of Printing"), "",N_("Shows the history of print outs for this score. Only saved documents have their printing recorded"),G_CALLBACK (display_printhistory)},
 {"PrintPart", GTK_STOCK_PRINT, N_("Print Part"), "",N_("Typesets the current part (the one containing the cursor)."),G_CALLBACK (printpart_cb)},
 {"Indexing", NULL, N_("Indexing"), "",N_("Menu:\nCommands to Index directories of Denemo Scores.")},
 {"Close", GTK_STOCK_CLOSE, N_("Close Score"), "",N_("Close the current score. Other scores (tabs) will stay open"),G_CALLBACK (close_gui_with_check)},
@@ -258,6 +258,7 @@
 {"Undo", GTK_STOCK_UNDO, N_("Undo"), "",N_("Undoes one (more) step of your edits to the music in the Display Window. Does not work for titles, settings etc - repeat the command for those."),G_CALLBACK (undowrapper)},
 {"Redo", GTK_STOCK_REDO, N_("Redo"), "",N_("Redoes the next of the steps you have Undone"),G_CALLBACK (redowrapper)},
 {"Select", NULL, N_("Select"), "",N_("Selecting stretches of notes")},
+{"ObjectAtCursor", NULL, N_("Object At Cursor"), "",N_("Editing the object at the cursor")},
 {"ExtendSelect", NULL, N_("Create and Extend Selection"), "",N_("Create/Extend the selection.")},
 {"Copy", GTK_STOCK_COPY, N_("Copy"), "",N_("Copy the music selected to the Denemo clipboard"),G_CALLBACK (copywrapper)},
 {"Cut", GTK_STOCK_CUT, N_("Cut"), "",N_("Cut the music selected to the Denemo clipboard"),G_CALLBACK (cutwrapper)},
@@ -300,7 +301,7 @@
 {"InsertStem", NULL, N_("Auto Stemming"), "",N_("Inserts a stem neutral object. After this automatic stem directions are active. You can click on this tag and use Sharpen/StemUp etc commands to change stem direction"),G_CALLBACK (stem_directive_insert)},
 {"AddVerse", NULL, N_("Add Lyric Verse"), "",N_("Add a verse of lyrics"),G_CALLBACK (add_verse)},
 {"DeleteVerse", NULL, N_("Delete Verse"), "",N_("Deletes current verse of lyrics from current voice"),G_CALLBACK (delete_verse)},
-{"EditFiguredBass", NULL, N_("Insert/Edit Figured Bass"), "",N_("Add a bass figure to the current note. Use | sign to split the duration of a note so as to have multiple figures on one note. See Lilypond docs for other notation"),G_CALLBACK (figure_insert)},
+{"EditFiguredBass", NULL, N_("Insert/Edit Figured Bass"), "",N_("Add a bass figure to the current note. Use | sign to split the duration of a note so as to have multiple figures on one note. Directly insert the LilyPond syntax for the current note by enclosing it with $ signs. See Lilypond docs for other notation"),G_CALLBACK (figure_insert)},
 {"DeleteFiguredBass", NULL, N_("Delete Figures"), "",N_("Delete the figured bass on the current staff"),G_CALLBACK (delete_figured_bass)},
 {"DeleteChordSymbols", NULL, N_("Delete Chord Symbols"), "",N_("Delete the chord symbols on the current staff"),G_CALLBACK (delete_fakechords)},
 {"HideFiguredBass", NULL, N_("Hide Figures (Print)"), "",N_("Hide the figured bass on the current staff on printing"),G_CALLBACK (hide_figured_bass)},
@@ -320,17 +321,16 @@
 {"EditClefDirective", NULL, N_("Edit Clef Directives"), "",N_("Edit any directives attached to clef."),G_CALLBACK (edit_clef_directive)},
 {"EditTimesigDirective", NULL, N_("Edit Time Signature Directives"), "",N_("Edit any directives attached to time signature."),G_CALLBACK (edit_timesig_directive)},
 {"EditKeysigDirective", NULL, N_("Edit Key Signature Directives"), "",N_("Edit any directives attached to key signature."),G_CALLBACK (edit_keysig_directive)},
-{"DeleteDirective", NULL, N_("Delete a Directive"), "",N_("Delete a directive attached to chord/note at cursor."),G_CALLBACK (delete_chord_or_note_directive)},
 {"NavigationMenu", NULL, N_("Navigation"), "",N_("Moving the cursor within the current movement, setting bookmarks, seeking things in the score")},
 {"GoToMeasure", NULL, N_("Go to Measure"), "",N_("Opens a dialog for going to a numbered measure"),G_CALLBACK (tomeasurenum)},
-{"GoToBeginning", GTK_STOCK_GOTO_FIRST, N_("Go to Beginning"), "",N_("Cursor to start of staff/voice, extending selection if any"),G_CALLBACK (tohome)},
-{"GoToEnd", GTK_STOCK_GOTO_LAST, N_("Go to End"), "",N_("Cursor to end of staff/voice, extending selection if any"),G_CALLBACK (toend)},
+{"GoToBeginning", GTK_STOCK_GOTO_FIRST, N_("Select to Beginning"), "",N_("Cursor to start of staff/voice, extending selection if any"),G_CALLBACK (tohome)},
+{"GoToEnd", GTK_STOCK_GOTO_LAST, N_("Select to End"), "",N_("Cursor to end of staff/voice, extending selection if any"),G_CALLBACK (toend)},
 {"MoveToBeginning", GTK_STOCK_GOTO_FIRST, N_("Move to Staff/Voice Beginning"), "",N_("Cursor to start of staff/voice, without extending selection if any"),G_CALLBACK (movetostart)},
 {"MoveToEnd", GTK_STOCK_GOTO_LAST, N_("Move to Staff/Voice End"), "",N_("Cursor to end of staff/voice, without extending selection if any"),G_CALLBACK (movetoend)},
 {"NextMovement", NULL, N_("Next Movement"), "",N_("Go to the next movement"),G_CALLBACK (next_movement)},
 {"PreviousMovement", NULL, N_("Previous Movement"), "",N_("Go to the previous movement"),G_CALLBACK (prev_movement)},
 {"DeleteMovement", NULL, N_("Delete Movement"), "",N_("Delete the current movement"),G_CALLBACK (delete_movement)},
-{"Play", GTK_STOCK_MEDIA_PLAY, N_("Play"), "",N_("Playback from start marker to end marker (Set these markers in the playback controls)"),G_CALLBACK (ext_midi_playback)},
+{"Play", GTK_STOCK_MEDIA_PLAY, N_("Play"), "",N_("Playback from start marker to end marker (Set these markers in the playback controls). Pause playback if already playing."),G_CALLBACK (ext_midi_playback)},
 {"Stop", GTK_STOCK_MEDIA_STOP, N_("Stop"), "",N_("Stop Playback"),G_CALLBACK (stop_midi_playback)},
 {"PlaybackProperties", GTK_STOCK_PROPERTIES, N_("Playback Properties"), "",N_("Allows you to specify properties used in playing back (midi)"),G_CALLBACK (playback_properties_change)},
 {"Help", NULL, N_("Browse Manual"), "",N_("Opens a browser on the user manual"),G_CALLBACK (browse_manual)},
@@ -409,6 +409,7 @@
 {"Beaming", NULL, N_("Beaming"), "",N_("Menu:\nBeaming - controlling which notes are beamed together")},
 {"Conditional Directives", NULL, N_("Conditional Directives"), "",N_("Menu:\nFor making directives apply only to one score layout or be omitted from one score layout")},
 {"MIDI", NULL, N_("MIDI"), "",N_("Menu:\nFor issuing MIDI instructions during playback at the time indicated by the current cursor position.")},
+{"Audio", NULL, N_("Audio"), "",N_("Menu:\nFor commands related to audio as opposed to MIDI.")},
 {"Keyboard", NULL, N_("PC Keyboard"), "",N_("Menu:\nChoose between different ways of entering notes from the computer keyboard.")},
 {"Mouse", NULL, N_("Mouse"), "",N_("Menu:\nChoose between different ways of using the mouse.")},
 {"PrintTranspositions", NULL, N_("Print Transposed"), "",N_("Menu:\nTransposing the score when typesetting.")},
