@@ -74,10 +74,13 @@ initprefs (void)
 #ifdef G_OS_WIN32
   ret->browser = g_string_new ("");     //use file association
   ret->graphicseditor = g_string_new (g_build_filename (get_system_bin_dir (), "..\\..\\..\\Inkscape\\inkscape.exe", NULL));       //the likely place for Inkscape to be installed, as we are not shipping it yet.
+  ret->ghostscript = g_string_new ("C:\\Program Files\\gs\\gs9.55.0\\bin\\gswin64c.exe");       //???
+
   ret->imageviewer = g_string_new ("");
 #else /* !G_OS_WIN32 */
   ret->browser = g_string_new ("firefox");
   ret->graphicseditor = g_string_new ("inkscape");
+  ret->ghostscript = g_string_new ("gs");
   ret->imageviewer = g_string_new ("eog");
 #endif /* !G_OS_WIN32 */
   set_default_lilypond_path ();
@@ -101,7 +104,7 @@ initprefs (void)
   ret->newbie = TRUE;
   ret->persistence = TRUE;
   ret->learning = TRUE;
-  ret->menunavigation = TRUE;
+  ret->menunavigation = FALSE;
   ret->immediateplayback = TRUE;
   ret->measureswitchsound = 75;
   ret->manualtypeset = FALSE;
@@ -131,11 +134,12 @@ initprefs (void)
   ret->portmidi_input_device = g_string_new ("default");
   ret->portmidi_output_device = g_string_new ("none");//Denemo has no code to output MIDI in real time, this turns off the setting up of the channel
 
+  ret->recording_timeout = 1000;
   gchar *soundfontpath = find_denemo_file(DENEMO_DIR_SOUNDFONTS, "A320U.sf2");
 
   ret->fluidsynth_soundfont = g_string_new (soundfontpath);
   ret->pitchspellingchannel = 15;
-  ret->pitchspellingprogram = 17;
+  ret->use_pitchspelling = 1;
 
   ret->saveparts = FALSE;
   ret->spillover = TRUE;
@@ -333,7 +337,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
         READINTXMLENTRY (lastmeasure)
         READINTXMLENTRY (laststaff)
         READINTXMLENTRY (pitchspellingchannel)
-        READINTXMLENTRY (pitchspellingprogram)
+        READINTXMLENTRY (use_pitchspelling)
 
         READBOOLXMLENTRY (persistence)
         READBOOLXMLENTRY (cursor_highlight)
@@ -381,6 +385,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
         READXMLENTRY (portaudio_device)
         READINTXMLENTRY (portaudio_sample_rate)
         READINTXMLENTRY (portaudio_period_size)
+        READINTXMLENTRY (recording_timeout)
         READINTXMLENTRY (maxrecordingtime)
         READXMLENTRY (portmidi_input_device)
         READXMLENTRY (portmidi_output_device)
@@ -471,7 +476,7 @@ get_int_pref (gchar * prefname)
     GETINTPREF (lastmeasure)
     GETINTPREF (laststaff)
     GETINTPREF (pitchspellingchannel)
-    GETINTPREF (pitchspellingprogram)
+    GETINTPREF (use_pitchspelling)
     GETINTPREF (mode)
     GETINTPREF (resolution)
     GETINTPREF (animation_steps)
@@ -495,12 +500,13 @@ return 0;
 gchar *
 get_string_pref (gchar * prefname)
 {
-  if (*prefname == 0)
-    return NULL;
-
+	if (*prefname == 0)
+		return NULL;
     GETSTRINGPREF (imageviewer)
     GETSTRINGPREF (profile)
     GETSTRINGPREF (username)
+    GETSTRINGPREF (graphicseditor)   
+    GETSTRINGPREF (ghostscript)   
     GETSTRINGPREF (password)
     GETSTRINGPREF (denemopath)
     GETSTRINGPREF (temperament)
@@ -768,6 +774,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
 
     WRITEXMLENTRY (lilypath)
     WRITEXMLENTRY (graphicseditor)
+    WRITEXMLENTRY (ghostscript)
     WRITEXMLENTRY (fontname)
     WRITEINTXMLENTRY (fontsize)
     WRITEXMLENTRY (imageviewer)
@@ -793,7 +800,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     WRITEINTXMLENTRY (lastmeasure)
     WRITEINTXMLENTRY (laststaff)
     WRITEINTXMLENTRY (pitchspellingchannel)
-    WRITEINTXMLENTRY (pitchspellingprogram)
+    WRITEINTXMLENTRY (use_pitchspelling)
 
     WRITEBOOLXMLENTRY (persistence)
     WRITEBOOLXMLENTRY (cursor_highlight)
@@ -846,6 +853,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     WRITEBOOLXMLENTRY (fluidsynth_reverb)
     WRITEBOOLXMLENTRY (fluidsynth_chorus)
     WRITEINTXMLENTRY (dynamic_compression)
+    WRITEINTXMLENTRY (recording_timeout)
     WRITEBOOLXMLENTRY (damping)
     WRITEINTXMLENTRY (zoom)
     WRITEINTXMLENTRY (system_height)
