@@ -17,23 +17,6 @@
 #define DENEMO_CAUTIONARY (3)
 
 #define HIGHLIGHT_OFFSET (20)   /* Fairly arbitrary value to transform codes '0', '1' ... to a new range with the meaning highlight the whole-note, half-note, ..., glyph */
-#define MAXEXTRASPACE (150)     /* maximum space for ledger lines, for sanity */
-
-#define LINE_SPACE 10
-#define HALF_LINE_SPACE 5
-#define NO_OF_LINES 5
-#define STAFF_HEIGHT (LINE_SPACE * (NO_OF_LINES - 1))
-#define LYRICS_HEIGHT (STAFF_HEIGHT/2)
-#define MID_STAFF_HEIGHT 2*LINE_SPACE
-/*#define LEFT_MARGIN 20 now variable for braces to take space */
-//#define KEY_MARGIN (LEFT_MARGIN+35)
-#define SPACE_FOR_TIME 35
-#define RIGHT_MARGIN 20
-#define SPACE_FOR_BARLINE 10
-#define HALF_BARLINE_SPACE 5
-#define WHOLE_NUMTICKS 1536
-#define FONT "Sans 9"
-#define TIMESIGFONT "Sans 24"
 
 #ifndef g_info
 #ifdef G_HAVE_ISO_VARARGS
@@ -124,6 +107,7 @@ GtkWidget *infodialog (gchar * msg);
 
 GtkWindow *progressbar (gchar * msg, gpointer callback);
 void progressbar_stop (void);
+void keep_alive (void);
 void busy_cursor (GtkWidget * area);
 void normal_cursor (GtkWidget * area);
 void headerfields (GtkWidget * dialog, GtkListStore * list_store, GtkTreeIter * iter, DenemoMovement * si, gboolean isdialog);
@@ -135,6 +119,7 @@ const gchar *get_system_data_dir (void);
 /* UNUSED
 const gchar *get_system_conf_dir (void);
 */
+gchar *make_temp_dir (gboolean removal);
 const gchar *get_system_locale_dir (void);
 const gchar *get_system_bin_dir (void);
 const gchar *get_system_font_dir (void);
@@ -153,6 +138,7 @@ gchar *music_font (gchar * str);
 void set_title_bar (DenemoProject * gui);
 void score_status (DenemoProject * gui, gboolean change);
 void write_status (DenemoProject * gui);
+void truncate_label (GtkWidget *label, gchar *str);
 gboolean confirm (gchar * primary, gchar * secondary);
 gboolean confirm_first_choice (gchar *title, gchar * primary, gchar * secondary);
 gboolean choose_option (gchar * title, gchar * primary, gchar * secondary);
@@ -281,6 +267,36 @@ if(!action && param){\
      if(nothing)\
       param_name1=values?values->str:NULL;\
 }
+#define GET_5PARAMS(action, param, param_name1, param_name2, param_name3, param_name4, param_name5) \
+G_GNUC_UNUSED gchar * query = NULL;\
+gchar * param_name1 = NULL;\
+gchar * param_name2 = NULL;\
+gchar * param_name3 = NULL;\
+gchar * param_name4 = NULL;\
+gchar * param_name5 = NULL;\
+  DenemoScriptParam dummy;\
+  dummy.string=NULL;\
+  if(param==NULL)\
+    param = &dummy;\
+  param->status = FALSE;\
+if(!action && param){\
+    GString *values = ((DenemoScriptParam *)param)->string;\
+    gboolean nothing=TRUE;\
+    if(values) {\
+     gchar *str;\
+     guint i;\
+       for(i=0;i<values->len;i+=strlen(values->str+i)+1) {\
+          UTILS_H_PARAM_ASSIGN(query)\
+          UTILS_H_PARAM_ASSIGN(param_name1)\
+          UTILS_H_PARAM_ASSIGN(param_name2)\
+          UTILS_H_PARAM_ASSIGN(param_name3)\
+          UTILS_H_PARAM_ASSIGN(param_name4)\
+          UTILS_H_PARAM_ASSIGN(param_name5)\
+       }\
+     }\
+     if(nothing)\
+      param_name1=values?values->str:NULL;\
+}
 
 gchar *get_option (gchar * title, gchar * str, gint length);
 void console_output (gchar * text);
@@ -297,6 +313,7 @@ void init_denemo_notenames (void);
 gint get_widget_height (GtkWidget * w);
 gint get_widget_width (GtkWidget * w);
 void switch_back_to_main_window (void);
+gboolean window_keypress_event (GtkWidget * widget, GdkEventKey * event);
 void use_markup (GtkWidget * widget);
 
 typedef enum
@@ -335,6 +352,10 @@ gchar *find_denemo_file (DenemoDirectory dir, gchar * filename);
 gchar *escape_scheme (gchar * input);
 gchar *time_spent_editing (void);
 void reset_editing_timer (void);
+gboolean modifier_held_down (gint modifier);
+
+gboolean shift_held_down (void);
+gboolean control_held_down (void);
 gboolean shift_held_down (void);
 
 #if GTK_MAJOR_VERSION == 2
