@@ -19,6 +19,7 @@
 
 
 #include <stdio.h>
+#include <math.h>
 #include <sndfile.h>
 #include <fcntl.h>
 #include <string.h>
@@ -37,7 +38,7 @@ recorded_audio_filename (void)
 }
 
 gboolean
-export_recorded_audio ()
+export_recorded_audio (const gchar *outname)
 {
   const gchar *filename = recorded_audio_filename ();
   SF_INFO out;
@@ -45,9 +46,13 @@ export_recorded_audio ()
     {
       gsize length;
       float *data;
-      if (g_file_get_contents (filename, (gchar **)&data, &length, NULL))
+      if (g_file_get_contents (filename, (gchar **)&data, &length, NULL) && (length>0))
         {
-          gchar *outfile = file_dialog ("Give output audio file name, with .ogg or .wav extension", FALSE, Denemo.prefs.denemopath->str);
+		  gchar *outfile;
+          if (outname==NULL)
+			outfile = file_dialog ("Give output audio file name, with .ogg or .wav extension", FALSE, Denemo.prefs.denemopath->str);
+		  else
+			outfile = g_strdup (outname);
           if (outfile)
             {
               gint len = strlen (outfile);
@@ -61,14 +66,30 @@ export_recorded_audio ()
                     {
                       out.format = SF_FORMAT_WAV | SF_FORMAT_PCM_16;
                     }
-                  out.channels = 1;
+                  out.channels = 2;
                   out.samplerate = 44100;
                   gpointer outsnd = sf_open (outfile, SFM_WRITE, &out);
                   if (outsnd)
                     {
-                      sf_write_float (outsnd, data, length/sizeof(float));
+					  gsize i;
+					  gboolean silence = TRUE;
+					  
+					  progressbar (_("Saving audio .. please wait"), NULL);
+					  for (i=0;i<length/sizeof(float);i++)
+						{
+							float out[2];
+							out[0] = out [1] = *(data+i);
+							if (silence && (fabs(*out) < 0.0001))
+								continue;
+							else
+								silence = FALSE;
+							sf_writef_float (outsnd, out, 1);
+							if (!(i%44100))
+								keep_alive ();
+						}
                       g_free(data);
                       sf_close (outsnd);
+                      progressbar_stop ();
                       return TRUE;
                     }
                   else
@@ -78,7 +99,6 @@ export_recorded_audio ()
                   g_free (outfile);
                 }
             }
-
         }
         else
         {
@@ -90,3 +110,4 @@ export_recorded_audio ()
     }
   return FALSE;
 }
+
