@@ -968,6 +968,36 @@ gdouble load_lilypond_midi (gchar * outfile, gboolean keep) {
     return 0.0;
 }
 
+
+static void do_tempo (smf_track_t* track, gint cur_tempo)
+{
+     smf_event_t* event = midi_tempo (cur_tempo);
+     smf_track_add_event_delta_pulses (track, event, 0);
+}
+  
+  
+static void generate_midi_from_recorded_notes (smf_t *smf)
+{
+	smf_track_t* track;
+	track = smf_track_new ();
+	smf_add_track (smf, track);
+	
+	do_tempo (track, Denemo.project->movement->tempo);
+	GList *g;
+	for (g=Denemo.project->movement->recording->notes; g; g=g->next)
+		{
+			DenemoRecordedNote *note = g->data;
+			if (note->timing>=0)
+				{
+					smf_event_t* event = smf_event_new_from_pointer (note->midi_event, 3);
+					smf_track_add_event_seconds (track, event, note->timing/(double)Denemo.project->movement->recording->samplerate);
+			}
+		}
+}
+
+
+
+
 /*
  * the main midi output system (somewhat large)
  */
@@ -996,7 +1026,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
   gint enshift;
   gint mid_c_offset;
   GList *curtone;
-  //gdouble fraction;
+  gboolean no_recorded_midi_track = TRUE;
 
   gint measurenum, last = 0;
 
@@ -1074,7 +1104,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
 
   /* just curious */
   time (&starttime);
-
+ 
   smf_t *smf = smf_new ();
   if(smf_set_ppqn (smf, MIDI_RESOLUTION))
     g_debug("smf_set_ppqn failed");
@@ -1083,9 +1113,17 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
  * end of headers and meta events, now for some real actions
  */
 
+//play recorded MIDI if the top (click track) staff is unmuted
+  if (Denemo.project->movement->recording  && Denemo.project->movement->recording->type == DENEMO_RECORDING_MIDI && !((DenemoStaff *) si->thescore->data)->mute)
+	{
+		generate_midi_from_recorded_notes (smf); 
+		no_recorded_midi_track = FALSE;
+	}
+
+
   //fraction = 1 / g_list_length (si->thescore);
 
-  /* iterate over all tracks in file */
+  /* iterate over all staffs in movement */
   //printf ("\nsi->stafftoplay in exportmidi = %i", si->stafftoplay);
   curstaff = si->thescore;
   if (si->stafftoplay > 0)
@@ -1105,6 +1143,9 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
                     global_transposition = directive->minpixels;
                 }
             }
+            
+ 
+		
   //for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
   while (curstaff)
     {
@@ -1123,11 +1164,9 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
       /* tempo */
       gint cur_tempo = si->tempo;
 
-      if (tracknumber == 1)
-        {                       //Do not set the tempo for later tracks as there may be tempo directives at the start of the first measure which libsmf will muddle up with any done here
-          event = midi_tempo (cur_tempo);
-          smf_track_add_event_delta_pulses (track, event, 0);
-        }
+      if (no_recorded_midi_track && (tracknumber == 1))
+        do_tempo (track, cur_tempo);//Do not set the tempo for later tracks as there may be tempo directives at the start of the first measure which libsmf will muddle up with any done here
+ 
       /* Midi Client/Port */
 //      track->user_pointer = (DevicePort *) device_manager_get_DevicePort(curstaffstruct->device_port->str);
 
@@ -1141,7 +1180,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
       prognum = curstaffstruct->midi_prognum;
 
       /* set selected midi program */
-      g_message ("Using channel %d prognum %d", midi_channel, prognum);
+      //g_message ("Using channel %d prognum %d", midi_channel, prognum);
       event = midi_change_event (MIDI_PROG_CHANGE, midi_channel, prognum);
       smf_track_add_event_delta_pulses (track, event, 0);
 
@@ -1258,7 +1297,9 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
           measure_is_empty = TRUE;
           measure_has_odd_tuplet = 0;
           ticks_at_bar = ticks_read;
-
+		
+		  ((DenemoMeasure*)curmeasure->data)->earliest_time = ticks_read * 60.0 / (cur_tempo * MIDI_RESOLUTION);
+		  
           /* iterate over objects in measure */
           for (curobjnode = (objnode *) ((DenemoMeasure*)curmeasure->data)->objects; curobjnode; curobjnode = curobjnode->next)
             {
@@ -1780,13 +1821,17 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
                 }
 
               //g_debug("Object type  0x%x Starts at %f Finishes %f\n",curobj->type, curobj->earliest_time, curobj->latest_time);
-            }                   // end of objects
-
+            } // end of objects in measure
+		
+	 // ((DenemoMeasure*)curmeasure->data)->latest_time = ticks_read * 60.0 / (cur_tempo * MIDI_RESOLUTION);
+	  
+    //  ((DenemoMeasure*)curmeasure->data)->earliest_time =
+    //       curmeasure->prev? ((DenemoMeasure*)curmeasure->prev->data)->latest_time : 0.0;
+//g_print ("staff %d measure earliest %f latest %f\n", tracknumber, ((DenemoMeasure*)curmeasure->data)->earliest_time, ((DenemoMeasure*)curmeasure->data)->latest_time);
       /*******************
        * Do some checking
        *******************/
 
-
           measurewidth = bars2ticks (1, timesigupper, timesiglower);
 
           if (measure_is_empty) // was (((DenemoMeasure*)curmeasure->data)->objects == NULL) //An empty measure - treat as whole measure silence
@@ -1815,7 +1860,7 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
       /*************************
        * Done with this measure
        *************************/
-
+		
 
         }                       /* Done with this staff */
 
@@ -1832,6 +1877,12 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
       else
         break;
     }
+    
+    
+  
+  
+   
+
 #if 0
 {
   smf_event_t *event;
@@ -1845,18 +1896,18 @@ exportmidi (gchar * thefilename, DenemoMovement * si)
   /********
    * Done!
    ********/
-   save_smf_to_file (smf, thefilename);
+  save_smf_to_file (smf, thefilename);
 
 
-  load_smf (si, smf);
+  load_smf (si, smf);//frees the old Denemo.project->movement->smf and points it to this one
 
 
 
   if (si->start_time < 0.0)
     si->start_time = 0.0;
-  if (si->end_time < 0.0)
+  if (si->end_time < 0.0 || (si->end_time > smf_get_length_seconds (smf)))
     si->end_time = smf_get_length_seconds (smf);
-  g_debug ("Start time %f end time %f\n", si->start_time, si->end_time);
+  g_print ("Start time %f end time %f\n", si->start_time, si->end_time);
 
   call_out_to_guile ("(FinalizeMidiGeneration)");
   return smf_get_length_seconds (smf);
