@@ -43,6 +43,7 @@
 #include "source/sourceaudio.h"
 #include "source/proof.h"
 #include "audio/pitchentry.h"
+#include "audio/midirecord.h"
 #include "audio/audiointerface.h"
 #include "printview/printview.h"
 
@@ -352,12 +353,35 @@ static void delete_all_rhythms (void)
 {
   DenemoProject *project = Denemo.project;
   GList *g;
-  for (g = project->rhythms;g;g=project->rhythms)
+  for (g = project->rhythms;g;g=project->rhythms) //the head of the list changes at each delete
     {
         delete_rhythm_pattern (g->data);
     }
 }
+static void delete_auto_rhythms (void) //delete rhythm patterns created automatically by Denemo
+{
+ DenemoProject *project = Denemo.project;
+  GList *g;
+  for (g = project->rhythms;g;)
+    {
+		RhythmPattern *r = g->data;
+        if (r->nickname && ((!g_strcmp0 (r->nickname->str, "Breve")) || 
+				(!g_strcmp0 (r->nickname->str, "Longa")) ||
+				 (!g_strcmp0 (r->nickname->str, "Maxima"))))
+			{ 
+				GList *h = g->next;
+				delete_rhythm_pattern (g->data);
+				call_out_to_guile ("(set! Snippet::Breve 0)");
+				call_out_to_guile ("(set! Snippet::Longa 0)");
+				call_out_to_guile ("(set! Snippet::Maxima 0)");
+				g = h;
+			}
+		else
+			g=g->next;
+    }	
+}
 static void enquire_rhythms (void) {
+delete_auto_rhythms ();
 if (Denemo.project->rhythms && choose_option (_("Music Snippets Can be Kept"), _("Drop Music Snippets"), _("Keep Music Snippets")))
     delete_all_rhythms ();
 }
@@ -377,6 +401,7 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
   gint result;
   gchar *zipfile = NULL;
   gboolean xml = FALSE;
+  gboolean musicxml = FALSE;
   result = 1;                   //FAILURE
 
   if (type == REPLACE_SCORE)
@@ -399,10 +424,10 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
                         found = try_to_find_file (base, zipfile);
                       
                        while (!found)
-                        { gchar *message = g_strdup_printf ("%s%s%s", _("Unable to find file: "), filename, _("\nChoose a directory (below which to search)\nin the next dialog"));
-                          gchar *path; 
-                          warningdialog (message);
-                          path = choose_directory (_("Give Toplevel Directory"), Denemo.prefs.denemopath->str, NULL);
+                        { gchar *message = g_strdup_printf ("%s%s", _("Not Found: "), filename);
+                          gchar *path = NULL; 
+                          if (choose_option (message, _("Browse for this file"), _("Ignore it")))
+							path = choose_directory (_("Give Toplevel Directory"), Denemo.prefs.denemopath->str, NULL);
                           if (path)
                             {
                               found = try_to_find_file (path, filename);
@@ -430,11 +455,14 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
                 result = importXML (zip, gui, type);
                 g_free (zip);
               }
+              
+            if ((result == 0) && midi_track_present () && gui->movement->thescore->next)
+				call_out_to_guile ("(RemoveClickTracks)");
         }
       else if (has_extension (filename, ".ly"))
         result = lyinput (filename);
       else if (has_extension (filename, ".mxml") || has_extension (filename, ".xml") || has_extension (filename, ".musicxml"))
-        result = mxmlinput (filename);
+        musicxml = TRUE, result = mxmlinput (filename);
       else if (has_extension (filename, ".mid") || has_extension (filename, ".midi"))
         result = (type==GUIDED_IMPORT)?guidedImportMidi (filename):importMidi (filename);
       else if (has_extension (filename, ".pdf") || has_extension (filename, ".PDF"))
@@ -467,7 +495,8 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
               else
                 {
                   gchar *sname = strip_path_and_extension (filename);
-                  set_gui_tabname (gui, sname);
+                  if (!musicxml)
+					set_gui_tabname (gui, sname);
                   g_free (sname);
                 }
             }
@@ -546,7 +575,7 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
                         DenemoDirective *direc = (DenemoDirective *)theobj->object;
                         if (direc->tag && !strcmp (direc->tag->str, "DenemoLink") &&direc->data)
                             {
-                                gchar *script = g_strdup_printf ("(d-OpenSource (scheme-escape \"%s\"))", direc->data->str);
+                                gchar *script = g_strdup_printf ("(d-OpenSource \"%s\")", escape_scheme (direc->data->str));
                                 call_out_to_guile (script);
                                 g_free (script);
                             }
@@ -1204,12 +1233,20 @@ file_dialog_response (GtkWidget * dialog, gint response_id, struct FileDialogDat
       gchar *file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       if (g_str_has_suffix (file_name, ".gz"))
         *(file_name + strlen (file_name) - strlen (".gz")) = 0;
+        
+        
+      if (data->template && !has_extension (file_name, ".denemo"))
+		{
+			gchar *filename = g_strdup_printf ("%s%s", file_name, ".denemo");
+			g_free (file_name);
+			file_name = filename;
+		}
       if (replace_existing_file_dialog (file_name, data->format_id))
         {
           gint status = filesel_save (gui, file_name, data->format_id, data->template);
           if (status == 0)
             score_status (gui, FALSE);
-          force_lily_refresh (gui);     //FIXME why is this here???
+          //force_lily_refresh (gui);     //FIXME why is this here???
         }
       g_free (file_name);
     }
@@ -1500,7 +1537,7 @@ export_interface(DenemoAction* action, DenemoScriptParam* param, gint format_id)
   else
     if (action==NULL || replace_existing_file_dialog(filename, format_id)){
       filesel_save (Denemo.project, filename, format_id, SAVE_COPY);
-      force_lily_refresh(Denemo.project);
+      //force_lily_refresh(Denemo.project);
     }
 }
 
