@@ -215,6 +215,7 @@ gchar *get_lily_version_string (void)
 					NULL,
 					NULL,
 					&err);
+
 	if (err)
 		g_warning ("Returned %s with %s", out, err?err->message:"");
 	else
@@ -566,6 +567,7 @@ else
                                                                NULL, /* stderr */
                                                                &lily_err);
 
+
   if (lily_err)
     {
       g_critical ("Error launching lilypond %s in directory %s! Message is %s", arguments[0], locateprintdir (), lily_err->message);
@@ -610,6 +612,7 @@ generate_lilypond (gchar * lilyfile, gboolean part_only, gboolean all_movements)
     exportlilypond (lilyfile, gui, all_movements);
 }
 
+// for populating the Print View, cf export_pdf ()
 static void
 run_lilypond_for_pdf (gchar * filename, gchar * lilyfile)
 {
@@ -629,6 +632,15 @@ run_lilypond_for_pdf (gchar * filename, gchar * lilyfile)
   };
   run_lilypond (arguments);
 }
+//synchronous generation of outfile.pdf from input lilyfile
+void generate_pdf_from_lily_file (gchar *lilyfile, gchar *outfile)
+{
+	gboolean old = Denemo.non_interactive;
+	Denemo.non_interactive = 1;
+	run_lilypond_for_pdf (outfile, lilyfile);
+	Denemo.non_interactive = old;
+}
+
 static void
 run_lilypond_for_svg (gchar * filename, gchar * lilyfile)
 {
@@ -941,7 +953,7 @@ export_png (gchar * filename, GChildWatchFunc finish, DenemoProject * gui)
  * Does all the export pdf work.
  * calls exportmudela and then
  * runs lilypond to a create a filename.pdf
- *
+ *  Called by (d-ExportPDF ...). The Print View is populated by run_lilypond_for_pdf ()
  *  @param filename filename to save score to
  *  @param gui pointer to the DenemoProject structure
  */
@@ -969,7 +981,7 @@ export_pdf (gchar * filename, DenemoProject * gui)
   gchar *arguments[] = {
     Denemo.prefs.lilypath->str,
     "-dgui",
-    "--loglevel=WARN",
+    "--loglevel=WARN", "-dno-point-and-click",
     "--pdf",
     local_include,
     include,
