@@ -396,7 +396,7 @@ static void compute_timings (gchar *base, GList *ids)
             gdouble nextTempoMoment = 0;
             gboolean incomingTempo = FALSE;
             while (2 == fscanf (fp, "%lf%10s", &moment, type))
-                {
+                { 
                //g_print ("moment %.2f %s latestMoment %.2f\n", moment, type, latestMoment);
                 moment /= 1000; //now events.txt stores ms to avoid decimal point
                   if (!strcmp (type, "tempo"))
@@ -409,10 +409,16 @@ static void compute_timings (gchar *base, GList *ids)
                                 } else g_warning ("Malformed events file");
                         }
                  else
-                    {
+                    {//breve duration is log = -1  if longa log = -2
+						//e.g.  0	rest	log = -1	2000	point-and-click 9 21
+					gchar basedur[10];
+					if (1 == fscanf (fp, "%4s", basedur))
+						{
+						if (!strcmp (basedur, "log"))
+							fscanf (fp, " %*s %*s");
                         if (!strcmp (type, "note"))
                             {
-                            if (4 == fscanf (fp, "%*s%lf%*s%d%d%d", &duration, &col, &line, &midi))
+								if (4 == fscanf (fp, " %lf%*s%d%d%d", &duration, &col, &line, &midi))
                                     {
                                        //g_print ("moment ... %.2f %s %.2f %d %d %d\n", moment, type, duration, col, line, midi);
                                        duration /= 1000; //now events.txt stores ms to avoid decimal point
@@ -445,10 +451,9 @@ static void compute_timings (gchar *base, GList *ids)
                                     else
                                     g_warning ("Could not parse type %s\n", type);
                             }
-
-                        else if(!strcmp (type, "rest"))
+                        else if (!strcmp (type, "rest"))
                             {
-                                if (3 == fscanf (fp, "%*s%lf%*s%d%d",  &duration, &col, &line))
+                                if (3 == fscanf (fp, " %lf%*s%d%d",  &duration, &col, &line))
                                     {
                                        //g_print ("moment ... %.2f %s %.2f %d %d %d\n", moment, type, duration, col, line, midi);
                                        duration /= 1000; //now events.txt stores ms to avoid decimal point
@@ -465,22 +470,22 @@ static void compute_timings (gchar *base, GList *ids)
                                         adjustedElapsedTime += elapsedTime * timeCoef;//g_print ("adjustedElapsedtime %f\n", adjustedElapsedTime);
                                         gchar *idStr;
                                         Timing *timing;
+										idStr = g_strdup_printf ("Rest-%d-%d" , line, col);
+										timing = get_svg_position (idStr, ids);
+										if(timing)
+											{
+											timing->line = line;
+											timing->col = col;
+											timing->time = adjustedElapsedTime;
+											add_note (timing);//g_print ("AdjustedElapsed time %.2f rest \n", adjustedElapsedTime);
+											}
+									} else
+										g_warning ("Could not parse type %s\n", type);
 
-
-
-                                            idStr = g_strdup_printf ("Rest-%d-%d" , line, col);
-                                            timing = get_svg_position (idStr, ids);
-                                            if(timing)
-                                                {
-                                                timing->line = line;
-                                                timing->col = col;
-                                                timing->time = adjustedElapsedTime;
-                                                add_note (timing);//g_print ("AdjustedElapsed time %.2f rest \n", adjustedElapsedTime);
-                                                }
-
-                                } //rest
-                            else g_warning ("Don't know how to handle %s\n", type);
-                            }
+							} //rest
+                          else 
+							g_warning ("Don't know how to handle %s\n", type);
+                          }
                             latestMoment = moment;
                         }// not tempo
                     } //while events
@@ -494,7 +499,25 @@ static void compute_timings (gchar *base, GList *ids)
 
     g_free (events);
 }
-
+static xmlNodePtr get_path_elem (xmlNodePtr rootElem)
+{
+xmlNodePtr childElem;
+FOREACH_CHILD_ELEM (childElem, rootElem)
+	{
+	//g_print ("Elem %s has transform %s\n", childElem->name, xmlGetProp (childElem, (xmlChar *) "transform"));
+	if (ELEM_NAME_EQ (childElem, "g"))
+		{
+			if (xmlGetProp (childElem, (xmlChar *) "transform"))
+				return childElem;
+			else
+				return get_path_elem (childElem);
+		}
+	else 			
+		if (xmlGetProp (childElem, (xmlChar *) "transform"))
+			return childElem;
+	}
+return NULL;
+}
 static GList * create_positions (gchar *filename)
 {
   GList *ret = NULL;
@@ -506,57 +529,53 @@ static GList * create_positions (gchar *filename)
   xmlKeepBlanksDefault (0);
   /* Try to parse the file(s). */
   filename = g_strdup (filename); //we may modify it
-  while (g_file_test (filename, G_FILE_TEST_EXISTS))
+  while (g_file_test (filename, G_FILE_TEST_EXISTS)) //multiple svg files
     {
       doc = xmlParseFile (filename);
       if (doc == NULL)
         {
           g_warning ("Could not read svg file %s", filename);
-         break;
+          break;
         }
         else
-        {//g_print ("Parsing %s\n", filename);
+        {
+		  //g_print ("Parsing %s\n", filename);
           rootElem = xmlDocGetRootElement (doc);
           xmlNodePtr childElem;
           FOREACH_CHILD_ELEM (childElem, rootElem)
           {
               if (ELEM_NAME_EQ (childElem, "g"))
-                { xmlNodePtr grandChildElem;
+                { xmlNodePtr pathElem;
                   gchar *id = xmlGetProp (childElem, (xmlChar *) "id");
-                     FOREACH_CHILD_ELEM (grandChildElem, childElem)
-                       {
-                         if (ELEM_NAME_EQ (grandChildElem, "g"))   //grouping to set color to black
-                          { xmlNodePtr greatgrandChildElem;
-                            FOREACH_CHILD_ELEM (greatgrandChildElem, grandChildElem)
-                                {
-                                    if (ELEM_NAME_EQ (greatgrandChildElem, "path"))
-                                        {
-                                            gchar *coords = xmlGetProp (greatgrandChildElem, (xmlChar *) "transform");
-                                            //g_print ("ID %s has Coords %s\n", id, coords);
-                                            if (id && coords)
-                                                {
-                                                gchar *data = g_strconcat (id, coords, NULL);
-                                                ret = g_list_append (ret, data);
-                                                xmlFree (id);
-                                                xmlFree (coords);
-                                                }
-                                        } else g_debug ("create_positions: Found group containing %s - ignoring.", greatgrandChildElem->name);
-                                    }
-                            }
-                        }
-                    }
-            }
-              if (doc != NULL)
-            xmlFreeDoc (doc);
-
-        }
-        //It may have spilt over into several svg files denemoprintA-page-1.svg etc
-       gint num_pos = strlen (filename)-5;//"<n>.svg"
+                  //g_print ("Elem %s has id %s\n", childElem->name, id);
+                  if (id)
+					{
+					  pathElem = get_path_elem (childElem);
+					  if (pathElem)
+						{
+							gchar *coords = xmlGetProp (pathElem, (xmlChar *) "transform");
+							//g_print ("ID %s has Coords %s\n", id, coords);
+							if (id && coords)
+								{
+								gchar *data = g_strconcat (id, coords, NULL);
+								ret = g_list_append (ret, data);
+								xmlFree (id);
+								xmlFree (coords);
+								}
+						}
+					}
+                }
+			}
+		}
+    if (doc != NULL)
+         xmlFreeDoc (doc);
+    //It may have spilt over into several svg files denemoprintA-page-1.svg etc
+    gint num_pos = strlen (filename)-5;//"<n>.svg"
        *(filename+num_pos) = *(filename+num_pos) + 1; //no attempt beyond 9 pages!
        //FIXME check that mtime of this file is later than the last, or delete old svg's before starting.
     }
-    g_free (filename);
-    //g_print ("Read %d ids from file %s\n", g_list_length (ret), filename);
+  //g_print ("Read %d ids from file %s\n", g_list_length (ret), filename);
+  g_free (filename);
   return ret;
 }
 static gint get_number_of_pages (gchar *base)
@@ -641,7 +660,7 @@ set_playback_view (void)
                 Denemo.playbackview = gtk_image_new_from_pixbuf (pb);
             //g_print ("Loaded %s via rsvg pixbuf loader", filename);
         } else
-        g_print ("\n\nThe rsvg pixbuf load of %s gave error: %s\n\n", filename, err?err->message: "no error return");
+        g_warning ("\n\nThe rsvg pixbuf load of %s gave error: %s\n\n", filename, err?err->message: "no error return");
 
 #else
       if(Denemo.playbackview)
@@ -829,7 +848,6 @@ static gboolean update_playback_view (void)
     //g_print ("Testing %d not equal %d or %d not equal %d \n", changecount, Denemo.project->changecount, Denemo.project->movement->changecount, Denemo.project->movement->smfsync);
  if ((changecount != Denemo.project->movement->changecount) || (Denemo.project->movement->changecount != Denemo.project->movement->smfsync))
         {
-        set_tempo ();
         call_out_to_guile (PartOnly?"(d-PlaybackView 'part)":"(d-PlaybackView)");//this installs the temporary directives to typeset svg and thendisplay_svg (gdouble scale, gboolean part)
         Denemo.project->movement->smfsync = Denemo.project->movement->changecount;
         changecount = Denemo.project->movement->changecount;
@@ -1159,7 +1177,6 @@ static void play_button (void)
 static void part_button (void)
 {
     PartOnly = TRUE;
-    set_tempo ();
     if (Denemo.project->movement->smf)
         AllPartsTypeset = confirm ( _("MIDI Already Present"), _("Keep this music while typesetting current part?"));
     call_out_to_guile ("(d-PlaybackView 'part)");//this installs the temporary directives to typeset svg and then
@@ -1168,7 +1185,6 @@ static void part_button (void)
 static void movement_button (void)
 {
     PartOnly = FALSE;
-    set_tempo ();
     call_out_to_guile ("(d-PlaybackView #f)");//this installs the temporary directives to typeset svg and then
 }
 
