@@ -27,6 +27,7 @@
 #define ToggleScoreLayout_STRING  "ToggleScoreLayout"
 #define ToggleCommandManager_STRING  "ToggleCommandManager"
 #define ToggleLyricsView_STRING  "ToggleLyricsView"
+#define ToggleSchemeView_STRING  "ToggleSchemeView"
 #define ToggleConsoleView_STRING  "ToggleConsoleView"
 #define ToggleScoreView_STRING  "ToggleScoreView"
 #define ToggleScoreTitles_STRING  "ToggleScoreTitles"
@@ -55,7 +56,8 @@ SCM scheme_get_relative_font_size (void);
 SCM scheme_initialize_script (SCM);
 SCM scheme_load_command (SCM);
 SCM scheme_activate_menu_item (SCM);
-SCM scheme_locate_dotdenemo (SCM);
+SCM scheme_locate_dotdenemo (void);
+SCM scheme_locate_temp_dir (void);
 SCM scheme_get_type (SCM);
 SCM scheme_get_lilypond (SCM);
 SCM scheme_refresh_lilypond (void);
@@ -70,10 +72,14 @@ SCM scheme_get_staffs_in_clipboard (SCM);
 SCM scheme_get_measures_in_staff (SCM);
 SCM scheme_inherit_staff_properties (void);
 SCM scheme_set_lines_in_staff (SCM);
+SCM scheme_staff_type (SCM type);
 SCM scheme_set_staff_range_lo (SCM);
 SCM scheme_set_staff_range_hi (SCM);
 SCM scheme_set_staff_range (void);
 SCM scheme_shorten_staff_height (SCM);
+SCM scheme_staff_set_space_above (SCM space);
+SCM scheme_staff_set_space_below (SCM space);
+SCM scheme_set_minimum_staff_spacing (SCM space);
 SCM scheme_set_color_of_staff (SCM);
 SCM scheme_get_staffs_in_movement (SCM);
 SCM scheme_get_movements_in_score (void);
@@ -136,10 +142,18 @@ SCM scheme_get_note_duration (void);
 SCM scheme_get_recorded_midi_tempo (SCM index);
 SCM scheme_get_imported_midi_track (SCM index);
 SCM scheme_delete_imported_midi (void);
-SCM scheme_midi_record (SCM script);
+SCM scheme_midi_record (void);
+SCM scheme_synchronize_recording (void);
+SCM scheme_reposition_recorded_midi (SCM secs_from_end);
+SCM scheme_recording_midi (void);
+SCM scheme_play_marked_midi (void);
+SCM scheme_toggle_play_recorded_midi (void);
+SCM scheme_delete_last_recorded_note (void);
 SCM scheme_get_current_midi_track (void);
 SCM scheme_get_imported_midi_tracks (void);
 SCM scheme_get_recorded_midi_duration (void);
+SCM scheme_get_time_at_cursor (void);
+SCM scheme_movement_duration (void);
 SCM scheme_set_duration_in_ticks (SCM);
 SCM scheme_get_duration_in_ticks (void);
 SCM scheme_get_base_duration_in_ticks (void);
@@ -205,6 +219,8 @@ SCM scheme_detach_quit_callback (void);
 SCM scheme_get_input_source (void);
 SCM scheme_popup_menu (SCM);
 SCM scheme_check_boxes (SCM checkboxlist, SCM title);
+SCM scheme_set_view_visibility (SCM windowname, SCM show);
+SCM scheme_get_view_visibility (SCM windowname);
 SCM scheme_get_target_info (void);
 SCM scheme_get_new_target (void);
 SCM scheme_get_new_point (void);
@@ -230,6 +246,9 @@ SCM scheme_progressbar (SCM);
 SCM scheme_progressbar_stop (void);
 SCM scheme_typeset_for_script (SCM);
 SCM scheme_print_typeset_pdf (void);
+SCM scheme_get_current_typeset_pdf (void);
+SCM scheme_execute_external_program (SCM args, SCM env);
+SCM scheme_create_pdf_from_lilyfile (SCM lilyfilename, SCM pdfbasename);
 SCM scheme_display_typeset_svg (SCM scaling, SCM part);
 SCM scheme_continous_typsetting (void);
 SCM scheme_get_char (void);
@@ -260,8 +279,12 @@ SCM scheme_virtual_keyboard (SCM);
 SCM scheme_toggle_playalong (void);
 SCM scheme_toggle_conduct (void);
 SCM scheme_compute_midi_note_durations (void);
+SCM scheme_get_marked_midi_note_as_lilypond (void);
 SCM scheme_get_marked_midi_note (void);
+SCM scheme_set_marked_midi_note (SCM pos);
 SCM scheme_get_marked_midi_note_seconds (void);
+SCM scheme_get_midi_recording_duration (void);
+SCM scheme_midi_recording_offset (SCM leadin);
 SCM scheme_mark_first_note_onset (void);
 SCM scheme_advance_marked_midi (SCM amount);
 SCM scheme_insert_marked_midi_note (void);
@@ -290,6 +313,9 @@ SCM scheme_set_saved (SCM);
 SCM scheme_changecount (SCM);
 SCM scheme_get_saved (SCM);
 SCM scheme_mark_status (SCM);
+SCM scheme_selection_start_staff (SCM);
+SCM scheme_selection_end_staff (SCM);
+SCM scheme_get_selection (void);
 SCM scheme_get_help (SCM);
 SCM scheme_email_help (SCM);
 SCM scheme_load_keybindings (SCM);
@@ -297,7 +323,6 @@ SCM scheme_save_keybindings (SCM);
 SCM scheme_clear_keybindings (SCM);
 SCM scheme_load_commandset (SCM);
 SCM scheme_zoom (SCM);
-SCM scheme_master_tempo (SCM);
 SCM scheme_movement_tempo (SCM);
 SCM scheme_master_volume (SCM);
 SCM scheme_staff_master_volume (SCM);
@@ -312,6 +337,7 @@ SCM scheme_restart_play (void);
 SCM scheme_staff_to_play (SCM);
 SCM scheme_get_midi_on_time (void);
 SCM scheme_get_midi_off_time (void);
+SCM scheme_get_rightmost_time (void);
 SCM scheme_midi_in_append_edit (void);
 SCM scheme_midi_in_checking (void);
 SCM scheme_midi_in_listening (void);
@@ -344,9 +370,11 @@ SCM scheme_select_next_layout (void);
 SCM scheme_select_first_layout (void);
 SCM scheme_select_next_custom_layout (void);
 SCM scheme_select_first_custom_layout (void);
-SCM scheme_get_omit_criterion (void);
-SCM scheme_set_omit_criterion (SCM name);
-SCM scheme_get_omit_criteria (void);
+SCM scheme_get_include_criterion (void);
+SCM scheme_set_include_criterion (SCM name);
+SCM scheme_get_include_criteria (void);
+SCM scheme_create_include_criterion (SCM optional_name);
+SCM scheme_get_include_criteria_on_directive (SCM tag, SCM type);
 SCM scheme_get_id_for_name (SCM name);
 SCM scheme_get_filename (void);
 SCM scheme_clear_filename (void);
@@ -364,7 +392,9 @@ SCM scheme_choose_file (SCM, SCM, SCM);
 SCM scheme_choose_directory (SCM, SCM, SCM);
 SCM scheme_edit_graphics (SCM, SCM);
 SCM scheme_open_source (SCM);
-SCM scheme_export_recorded_audio (void);
+SCM scheme_export_recorded_audio (SCM name);
+SCM scheme_toggle_recording_audio (void);
+SCM scheme_recording_audio (void);
 SCM scheme_open_source_file (SCM);
 SCM scheme_open_proofread_file (SCM);
 SCM scheme_open_source_audio_file (SCM);
