@@ -20,7 +20,11 @@
 #include "source/source.h"
 #include "core/view.h"
 #include "core/utils.h"
+#ifdef USE_ATRIL
+#include <atril-view.h>
+#else
 #include <evince-view.h>
+#endif
 
 static gboolean Dragging;
 static GdkPoint DragStart, DragEnd;
@@ -45,6 +49,9 @@ static gboolean window_state (GtkWidget *win, GdkEventWindowState  *event)
 static gboolean is_uniconified (GtkWidget *win)
   {
     //g_print("Source %x is %s uniconified\n", win,  g_object_get_data (G_OBJECT(win),  "uniconified")? "IS":"IS NOT!!!!");
+#ifdef G_OS_WIN32
+	return TRUE;
+#endif
     return (gboolean)GPOINTER_TO_INT(g_object_get_data (G_OBJECT(win),  "uniconified"));
   }
   
@@ -119,7 +126,10 @@ overdraw (cairo_t * cr, GtkWidget* view)
         for (g=Highlights;g;g = g->next)
             {
                GdkRectangle *r = (GdkRectangle*)g->data;
-               cairo_set_source_rgba (cr, 0.5, 0.5, 0.5, 0.5);
+               if (r->width > r->height)
+					cairo_set_source_rgba (cr, 0.5, 0.5, 0.5, 0.5);
+			   else
+					cairo_set_source_rgba (cr, 1.0, 0.0, 0.0, 0.5);
                cairo_rectangle (cr, r->x * scale, r->y * scale, abs(r->width)* scale, abs(r->height)* scale);
                // cairo_rectangle (cr, r->x , r->y , abs(r->width), abs(r->height));
                cairo_fill (cr); // cairo_clip (cr);//
@@ -129,7 +139,10 @@ overdraw (cairo_t * cr, GtkWidget* view)
     {
         gdouble xx = MIN (DragStart.x, DragEnd.x);
         gdouble yy = MIN (DragStart.y, DragEnd.y);
-      cairo_set_source_rgba (cr, 0.5, 0.5, 0.5, 0.5);
+        if ((abs(DragStart.y-DragEnd.y)>0) && (abs(DragStart.x-DragEnd.x)/abs(DragStart.y-DragEnd.y)) < 1)
+			 cairo_set_source_rgba (cr, 0.7, 0.0, 0.0, 0.5);
+		else	
+			cairo_set_source_rgba (cr, 0.5, 0.5, 0.5, 0.5);
       cairo_rectangle (cr, xx * scale, yy * scale, abs(DragStart.x-DragEnd.x) * scale, abs(DragStart.y-DragEnd.y) * scale);
       cairo_fill (cr);
       cairo_set_source_rgb (cr, 0, 0, 0);
@@ -214,7 +227,7 @@ static void remove_highlights (GtkWidget *view)
 
 static void help (void)
  {
-     infodialog (_("To insert a link at the Denemo cursor position to a point in this document\nright-click on the point.\nLater you will be able to re-open the document at that point by right clicking on the link in the Denemo display.\nTo shade in gray parts of the source that you don't want to see drag over the area.\nUse this for transcribing from a score with many parts to ease following the part from system to system.\nClick on a grayed-out patch to remove it."));
+     infodialog (_("To insert a link at the Denemo cursor position to a point in this document\nright-click on the point.\nLater you will be able to re-open the document at that point by right clicking on the link in the Denemo display.\nTo shade in gray parts of the source that you don't want to see drag over the area.\nUse this for transcribing from a score with many parts to ease following the part from system to system.\nClick on a grayed-out patch to remove it.\nTo mark a place in the score for looking back at drag a line downwards which will show as a red mark - it is just another color of shading."));
  }
         
 static gboolean
@@ -268,12 +281,12 @@ static void popup_highlight_menu (GtkWidget *view, GList *highlight, GdkEventBut
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (help), NULL);
 
-  item = gtk_menu_item_new_with_label (_("Remove this Shading"));
+  item = gtk_menu_item_new_with_label (_("Remove this Shading/Marker"));
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   g_object_set_data (G_OBJECT (item), "fileview", g_object_get_data (G_OBJECT (view), "fileview"));
   g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (remove_highlight), highlight);
 
-  item = gtk_menu_item_new_with_label (_("Remove all Shading"));
+  item = gtk_menu_item_new_with_label (_("Remove all Shadings/Markers"));
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (remove_highlights), view);
   gtk_widget_show_all (menu);
@@ -329,16 +342,17 @@ button_press (EvView * view, GdkEventButton * event)
         {
       
       
-          //gchar *escaped = g_strescape(filename, "");
-          gchar *text = g_strdup_printf ("(InsertLink \"%s:%d:%d:%d\")", filename //escaped
+          gchar *escaped = escape_scheme(filename);
+          gchar *text = g_strdup_printf ("(InsertLink \"%s:%d:%d:%d\")", escaped
                       , (gint) (x / scale), (gint) (y / scale), page);
-         // g_free(escaped);
+          g_free(escaped);
           Mark.x = (x - MARKER / 2) / scale;
           Mark.y = (y - MARKER / 2) / scale;
           Mark.width = Mark.height = MARKER;
           if (!gdk_rectangle_intersect (&Mark, &candidate, NULL))
             OldMark = candidate;
           gtk_widget_queue_draw (GTK_WIDGET (view));
+          g_print ("Calling %s\n", text);
           call_out_to_guile (text);
           switch_back_to_main_window ();
       }
@@ -386,21 +400,6 @@ page_changed (EvDocumentModel *evdocumentmodel, gint old_page,gint new_page, gpo
           gtk_spin_button_set_value (GTK_SPIN_BUTTON(spinner), new_page+1.0);
     }
 
-static gboolean
-position_source_window (EvView * view)
-{
-  GtkWidget *top_vbox = gtk_widget_get_toplevel (GTK_WIDGET (view));
-  if (Denemo.project->source_scale)
-    {
-      //gtk_widget_set_size_request(GTK_WIDGET(top_vbox), Denemo.project->source_width, Denemo.project->source_height);
-      //EvDocumentModel *model = (EvDocumentModel*)g_object_get_data(G_OBJECT(view), "model");
-      //ev_document_model_set_scale(model, Denemo.project->source_scale/1000.0);
-      gtk_window_move (GTK_WINDOW (top_vbox), Denemo.project->source_x, Denemo.project->source_y);
-    }
-  else
-    gtk_window_present (GTK_WINDOW (top_vbox));
-  return FALSE;
-}
 
 static gchar *locate_file (gchar *filename) {
     if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {
@@ -413,7 +412,29 @@ static gchar *locate_file (gchar *filename) {
     return filename;
 }
 
+//~ typedef struct {
+  //~ GdkEventType type;
+  //~ GdkWindow *window;
+  //~ gint8 send_event;
+  //~ gint x, y;
+  //~ gint width;
+  //~ gint height;
+//~ } GdkEventConfigure;
 
+static gboolean window_configure_event (GtkWidget *widget,
+               GdkEventConfigure  *event, EvView *view)
+   {
+	EvDocumentModel *model = (EvDocumentModel *) g_object_get_data (G_OBJECT (view), "model");
+	Denemo.project->source_scale = (int) 1000 *ev_document_model_get_scale (model);
+	if(Denemo.project->source_scale == 0) 
+		g_warning("Scale of document is zero!!!");
+	Denemo.project->source_x = event->x;
+	Denemo.project->source_y = event->y;
+	Denemo.project->source_width = event->width;
+	Denemo.project->source_height = event->height;
+	//g_print ("configure wxh %dx%d x=%d y=%d scale %d\n", Denemo.project->source_width, Denemo.project->source_height, Denemo.project->source_x,Denemo.project->source_y,Denemo.project->source_scale);
+	return FALSE;
+   }
 static EvView *
 get_view (gchar * filename)
 {
@@ -422,6 +443,8 @@ get_view (gchar * filename)
   EvView *view = NULL;
   GList *g;
   filename = locate_file (filename);
+  if (!g_file_test (filename, G_FILE_TEST_EXISTS))
+	return NULL;
   for (g = FileViews; g; g = g->next)
     if (!strcmp (((fileview *) g->data)->filename, filename))
       return (((fileview *) g->data)->view);
@@ -447,8 +470,12 @@ get_view (gchar * filename)
   ev_view_set_model (view, model);
   GtkWidget *top_vbox = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   g_object_set_data (G_OBJECT(top_vbox), "uniconified", GINT_TO_POINTER(TRUE));
+#ifndef G_OS_WIN32
   g_signal_connect (G_OBJECT(top_vbox), "window-state-event", G_CALLBACK (window_state), NULL);
+#endif  
   
+  g_signal_connect (G_OBJECT (top_vbox), "key_press_event", G_CALLBACK (window_keypress_event), NULL);
+
   
   g_signal_connect (G_OBJECT(model), "page-changed", G_CALLBACK (page_changed), view);
   
@@ -458,10 +485,15 @@ get_view (gchar * filename)
   gtk_window_set_title (GTK_WINDOW (top_vbox), g_strdup_printf ("Denemo - Source File: %s", filename));
 
 
-  g_idle_add ((GSourceFunc) position_source_window, view);
+  //g_idle_add ((GSourceFunc) position_source_window, view);
+  g_signal_connect (G_OBJECT(top_vbox), "configure-event", G_CALLBACK (window_configure_event), (gpointer)view);
+  
   
   if (Denemo.project->source_scale)
-    gtk_window_set_default_size (GTK_WINDOW (top_vbox), Denemo.project->source_width, Denemo.project->source_height);
+    {
+		gtk_window_set_default_size (GTK_WINDOW (top_vbox), Denemo.project->source_width, Denemo.project->source_height);
+		gtk_window_move (GTK_WINDOW (top_vbox),Denemo.project->source_x, Denemo.project->source_y - 30 /*window decorations take space*/);
+	}
   else
     gtk_window_set_default_size (GTK_WINDOW (top_vbox), 600, 750);
 
@@ -547,41 +579,17 @@ open_source (gchar * filename, gint x, gint y, gint page)
   if (Denemo.non_interactive)
     return FALSE;
   EvView *eview = get_view (filename);
+  if (eview==NULL)
+	return FALSE;
   gboolean ret = position_view (eview, x, y, page);
   GtkWidget *spinner = (GtkWidget *)g_object_get_data (G_OBJECT (eview), "spinner");
   gtk_spin_button_set_value (GTK_SPIN_BUTTON(spinner), page+1.0);
+  write_status (Denemo.project);
   switch_back_to_main_window ();
   return ret;
 }
 
-
-//Finds the scale and position of the window (first) source file. Returns the Denemo.project->scale_* values if the window is not visible. Returns FALSE if none
-//FIXME, it would be better to set Denemo.project->scale_* values in a "configure" callback on the window.
-gboolean
-source_position (gint * x, gint * y, gint * width, gint * height, gint * scale)
-{
-  if (FileViews == NULL)
-    return FALSE;
-  EvView *view = ((fileview *) FileViews->data)->view;
-  GtkWindow *top = (GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (view));
-  if(gtk_widget_get_visible(GTK_WIDGET(top)))
-  {
-          gtk_window_get_position (top, x, y);
-          gtk_window_get_size (top, width, height);
-          EvDocumentModel *model = (EvDocumentModel *) g_object_get_data (G_OBJECT (view), "model");
-          *scale = (int) 1000 *ev_document_model_get_scale (model);
-          if(!*scale) g_warning("Scale of document is zero!!!");
-  } else {
-        *x = Denemo.project->source_x;
-        *y = Denemo.project->source_y;
-        *scale = Denemo.project->source_scale;
-  }
-
-  return TRUE;
-}
-
-
-
+//moves the first un-iconized source window, on Windows iconized is not tracked
 gboolean
 move_source_window (gint x, gint y)
 {
