@@ -587,6 +587,12 @@ static gboolean hide_command_view (void)
     return TRUE;
 }
 
+gboolean command_center_keypress_event (GtkWidget * widget, GdkEventKey * event, keyboard_dialog_data *cbdata)
+{
+	if (cbdata->two_key == 0)
+		return window_keypress_event (widget, event);
+	return FALSE;
+}
 void
 command_center_select_idx (DenemoAction * dummy, gint command_idx)
 {
@@ -642,7 +648,7 @@ command_center_select_idx (DenemoAction * dummy, gint command_idx)
     }
    if(SearchEntry==NULL) {
     SearchEntry = gtk_entry_new ();
-        g_signal_connect(G_OBJECT(SearchEntry), "key-press-event", G_CALLBACK(search_entry_character), NULL);
+    g_signal_connect(G_OBJECT(SearchEntry), "key-press-event", G_CALLBACK(search_entry_character), NULL);
 
     SearchNext = gtk_button_new_with_label ("→");
     gtk_widget_set_tooltip_text (SearchEntry, _("Type search text here. Enter words that might be in the command label,\nor part of the text of a tooltip or the internal name.\nThe search is case insensitive. It goes on to the next match each time you enter letter that doesn't match the current command so check at each keypress.\nThe search re-starts from the top when you delete a letter."));
@@ -656,6 +662,8 @@ command_center_select_idx (DenemoAction * dummy, gint command_idx)
   command_tree_view = gtk_bin_get_child (GTK_BIN (command_view));
 
   Denemo.command_manager = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  g_signal_connect_after(G_OBJECT(Denemo.command_manager), "key-press-event", G_CALLBACK(command_center_keypress_event), &cbdata);
+
   gtk_window_set_title(GTK_WINDOW(Denemo.command_manager), (_("Command Center")));
   if (Denemo.prefs.newbie)
     gtk_widget_set_tooltip_text (Denemo.command_manager,
