@@ -20,16 +20,22 @@
 #include "display/draw.h"
 #include "core/view.h"
 #include "audio/audiointerface.h"
+#include "audio/midirecord.h"
 #include "export/exportmidi.h"
 
+#define HeightOfRecordingTrack (161) //includes the entire click track at the top
 
 static gboolean lh_down;
 static gdouble last_event_x;
 static gdouble last_event_y;
+static gint drag_display_x;
+static gint drag_display_y;
+#define DRAG_SCALE (20) //to make the dragging less sensitive
 static DenemoDirective *last_directive;
 typedef enum DragDirection { DRAG_DIRECTION_NONE = 0, DRAG_DIRECTION_UP, DRAG_DIRECTION_DOWN, DRAG_DIRECTION_LEFT, DRAG_DIRECTION_RIGHT} DragDirection;
 static enum DragDirection dragging_outside = DRAG_DIRECTION_NONE; //dragging to left or right outside window.
 
+static gint playback_brightness_shift = 0;
 /**
  * Get the mid_c_offset of an object or click from its height relative
  * to the top of the staff.
@@ -77,7 +83,7 @@ offset_from_height (gdouble height, enum clefs clef)
   return 0;
 }
 
-
+//height of cursor relative the the current staff. 0 is the top line of the staff, 40 the bottom line
 static gdouble
 get_click_height (DenemoProject * gui, gdouble y)
 {
@@ -119,11 +125,46 @@ get_click_height (DenemoProject * gui, gdouble y)
   //g_print("top staff is %d total %d staffs from top is %d click %f\n", gui->movement->top_staff, extra_space, staffs_from_top, click_height);
 
   return click_height;
-
-
-
 }
+//height of cursor relative the staff hovered over. 0 is the top line of the staff, STAFF_HEIGHT (ie 40) the bottom line
+static gdouble
+get_click_height_on_closest_staff (DenemoProject * gui, gdouble y)
+{
+  gdouble click_height;
+  gint staffs_from_top;
+  staffs_from_top = 0;
+  GList *curstaff;
+  DenemoStaff *staff;
+  gint extra_space = 0;
+  gint space_below = 0;
+  gint i;
+  curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1);
 
+  if (!(((DenemoStaff *) (gui->movement->currentstaff->data))->voicecontrol & DENEMO_PRIMARY))
+    staffs_from_top--;
+
+  for (i=0; curstaff; i++, curstaff = curstaff->next)
+    {
+      staff = (DenemoStaff *) curstaff->data;
+      //g_print ("%d from top, staff %d extra space %d (next is %d %d  %d) previous space_below = %d)\n", i, gui->movement->currentstaffnum, extra_space, staff->space_above, staff->space_shorten, staff->space_below, space_below);
+
+      if ((curstaff != Denemo.project->movement->currentstaff) && staff->hidden) continue;
+      if (staff->voicecontrol & DENEMO_PRIMARY)
+        extra_space += (staff->space_above - (i?staff->space_shorten:0)
+          + space_below);
+      click_height = y - (gui->movement->staffspace * staffs_from_top + gui->movement->staffspace / 4 + extra_space);
+      if (click_height>0 && click_height<STAFF_HEIGHT)
+        break;
+      if (staff->voicecontrol & DENEMO_PRIMARY)
+        {
+          space_below = 0;
+          staffs_from_top++;
+        }
+      space_below = MAX (space_below, ((staff->space_below) + (staff->verse_views ? LYRICS_HEIGHT : 0)));
+     // g_print("after extra space %d space_below %d\n", extra_space, space_below);
+    }
+  return click_height;
+}
 /**
  * Set the cursor's y position from a mouse click
  *
@@ -159,11 +200,9 @@ struct placement_info
   staffnode *the_staff;
   measurenode *the_measure;
   objnode *the_obj;
-  gboolean nextmeasure;
   gboolean offend;              //TRUE when the user has clicked beyond the last note, taking you into appending
-  gboolean at_edge; //TRUE when user clicked close (CURSOR_AT_EDGE) to right hand edge of scorearea.
 };
-#define CURSOR_AT_EDGE (60)
+
 /* find the primary staff of the current staff, return its staffnum */
 static gint
 primary_staff (DenemoMovement * si)
@@ -224,7 +263,6 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
       g_critical ("Array of measurewidths too small for leftmeasure %d\n", leftmeasurenum);
       return;
     }
-  pi->at_edge = (get_widget_width (Denemo.scorearea) -x) < CURSOR_AT_EDGE;
   pi->staff_number = staff_at ((gint) y, si);
   //g_debug("L/R %d %d got staff number %d\n", leftmeasurenum, rightmeasurenum, pi->staff_number);
   pi->measure_number = leftmeasurenum;
@@ -245,7 +283,6 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
       pi->measure_number++;
     }
   //g_debug("got to measure %d\n", pi->measure_number);
-  pi->nextmeasure = ((si->system_height > 0.5 || x_to_explain > GPOINTER_TO_INT (mwidthiterator->data)) && pi->measure_number >= rightmeasurenum);
 
   pi->the_staff = g_list_nth (si->thescore, pi->staff_number - 1);
   pi->the_measure = staff_nth_measure_node (pi->the_staff, pi->measure_number - 1);
@@ -401,8 +438,10 @@ perform_command (gint modnum, mouse_gesture press, gboolean left)
 
 static gboolean selecting = FALSE;
 static gboolean dragging_separator = FALSE;
-static gboolean dragging_audio = FALSE;
+static gboolean dragging_display = FALSE;
+static gboolean dragging_recording_sync = FALSE;
 static gboolean dragging_tempo = FALSE;
+static gboolean motion_started = FALSE;//once dragging_xxx is true and a motion_notify has come in this becomes true. Becomes false when dragging_xxx becomes true
 
 static gboolean
 change_staff (DenemoMovement * si, gint num, GList * staff)
@@ -517,20 +556,32 @@ static gint hidden_staff_line (gint line_height)
  *
  */
 gint
-scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
+scorearea_motion_notify (GtkWidget * widget, GdkEventMotion * event)
 {
   DenemoProject *gui = Denemo.project;
   static gboolean hovering_over_hidden = FALSE;
+  gint drag_y = event->y;
   if (gui == NULL || gui->movement == NULL)
     return FALSE;
   if (Denemo.scorearea == NULL)
     return FALSE;
     
+   gui->movement->hovering_over_midi_track = (gui->movement->recording && (event->y < HeightOfRecordingTrack*gui->movement->zoom));
+
   // this would avoid an interesting "cursor follow the pointer" mode, which we don't use because you would not be able to move the mouse pointer away e.g. to choose a menu without the Denemo Cursor moving...
   //if (selecting && lh_down && !Denemo.project->movement->markstaffnum)
   // selecting = lh_down = 0; 
   // it should never happen, so we don't need to guard against it.
-  
+  if (dragging_recording_sync || dragging_tempo) 
+	{
+		if ((!motion_started) )
+			{
+				gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), dragging_recording_sync?Denemo.GDK_SB_H_DOUBLE_ARROW:Denemo.GDK_CIRCLE);
+				if (is_playing ())
+				 return TRUE;// avoid crashing
+				motion_started = TRUE;
+			}
+	}
   gint allocated_height = get_widget_height (Denemo.scorearea);
   gint line_height = allocated_height * gui->movement->system_height;
   if(dragging_outside)
@@ -589,54 +640,69 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
         return TRUE;
       }
 
+  
+	
 
 
-  if(gui->movement->recording && dragging_audio)
+
+  if(gui->movement->recording && dragging_recording_sync)
     {
         if(gui->movement->recording->type == DENEMO_RECORDING_MIDI)
-        {
-            #if 0
-            //This is moving only the NoteOn, so it could be moved later than the note off, and indeed later than a later note in the stream
-            //- quite a bit more work needed to drag MIDI to correct the timing.
-            smf_event_t *midievent;
-            GList *marked_onset = gui->movement->marked_onset;
-            if(marked_onset)
-                {
-                midievent = ((DenemoRecordedNote *)marked_onset->data)->event;
-                gint shift =  2500*(event->x_root - last_event_x)/gui->movement->zoom;
-                g_debug (" %f (%f %f)",shift/(double)gui->movement->recording->samplerate,
-                    midievent->time_seconds,
-                    ((DenemoRecordedNote *)marked_onset->data)->timing/(double)gui->movement->recording->samplerate) ;
-
-                ((DenemoRecordedNote *)marked_onset->data)->timing += shift;
-
-                midievent->time_seconds += shift/(double)gui->movement->recording->samplerate;
-                }
-            #endif
-            g_warning("No drag for MIDI yet");
+        { //g_print ("motion notify recording & dragging sync\n\n");
+//FIXME repeated code:
+		  struct placement_info pi;
+		  pi.the_staff = NULL;
+		  if (event->y < 0)
+			get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+		  else
+			get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+		  if (pi.the_staff == NULL)
+			return TRUE;            //could not place the cursor
+			
+		  if ((pi.staff_number>1) && pi.the_measure != NULL)
+			{                       /*don't place cursor in a place that is not there nor on the MIDI track*/
+			  change_staff (gui->movement, pi.staff_number, pi.the_staff);
+			  gui->movement->currentmeasurenum = pi.measure_number;
+			  gui->movement->currentmeasure = pi.the_measure;
+			  gui->movement->currentobject = pi.the_obj;
+			  gui->movement->cursor_x = pi.cursor_x;
+			  gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) ((DenemoMeasure*)gui->movement->currentmeasure->data)->objects)));
+			  set_cursor_y_from_click (gui, event->y);
+			 }
+            //g_warning("Dragging for MIDI ... release on note");
             return TRUE;
         }
-
+//NOT Recording MIDI, so recording AUDIO
         gui->movement->recording->leadin -= 500*(event->x_root - last_event_x)/gui->movement->zoom;//g_debug("%d %d => %d\n", (int)(10*last_event_x), (int)(10*event->x_root), (int)(10*last_event_x) - (int)(10*event->x_root));
         last_event_x = event->x_root;
         update_leadin_widget ( gui->movement->recording->leadin/(double)gui->movement->recording->samplerate);
         gtk_widget_queue_draw(Denemo.scorearea);
         return TRUE;
     }
-  if(gui->movement->recording && dragging_tempo)
+  if (gui->movement->recording && (gui->movement->recording->type == DENEMO_RECORDING_AUDIO) && dragging_tempo)
     {
-        gdouble change = (event->x_root - last_event_x)/gui->movement->zoom;
-        last_event_x = event->x_root;
-        struct placement_info pi;
-        get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
-        change /= pi.measure_number;
-        update_tempo_widget ( change);
-        set_tempo ();
-        score_status (Denemo.project, TRUE);
-        exportmidi (NULL, gui->movement);
-        gtk_widget_queue_draw(Denemo.scorearea);
+        //~ gdouble change = (event->x_root - last_event_x)/gui->movement->zoom;
+        //~ last_event_x = event->x_root;
+        //~ struct placement_info pi;
+        //~ get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+        //~ change /= pi.measure_number;
+        //~ update_tempo_widget ( change);
+        //~ score_status (Denemo.project, TRUE);
+        //~ exportmidi (NULL, gui->movement);
+        //~ gtk_widget_queue_draw(Denemo.scorearea);
         return TRUE;
     }
+    else if (gui->movement->recording && (gui->movement->recording->type == DENEMO_RECORDING_MIDI) && dragging_tempo)
+		{
+			gdouble change = (event->x_root - last_event_x)/gui->movement->zoom;
+			if (change>0)
+				scale_recording (1.005);
+			else
+				scale_recording (0.995);
+			last_event_x = event->x_root;		
+			return TRUE;
+			
+		}
 #define DENEMO_MINIMUM_SYSTEM_HEIGHT (0.01)
 
 
@@ -652,10 +718,36 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
       return TRUE;
     }
 
+  if (dragging_display)
+    {
+      //g_print ("dragging display %d %d\n",(gint)event->x, (gint)event->y);
+      if (drag_display_x < 0)
+		{
+			drag_display_x = (gint)event->x/DRAG_SCALE;
+			drag_display_y = (gint)event->y/DRAG_SCALE;
+			return TRUE;
+		}
+	  if (drag_display_x > (gint)event->x/DRAG_SCALE)
+			call_out_to_guile ("(d-ShrinkMeasures)");
+	  if (drag_display_y > (gint)event->y/DRAG_SCALE)
+			call_out_to_guile ("(d-ShorterStaffs)");	
+		  if (drag_display_x < (gint)event->x/DRAG_SCALE)
+			call_out_to_guile ("(d-WidenMeasures)");
+	  if (drag_display_y < (gint)event->y/DRAG_SCALE)
+			call_out_to_guile ("(d-TallerStaffs)");		
+			
+	drag_display_x = (gint)event->x/DRAG_SCALE;
+	drag_display_y = (gint)event->y/DRAG_SCALE;
+				
+      draw_score_area();
+      return TRUE;
+    }
+
+
   if (line_height - ((int) event->y - 8) % line_height < 12)
-    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_SB_V_DOUBLE_ARROW);
+	   gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_SB_V_DOUBLE_ARROW);
   else
-    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
+       gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
 
   transform_coords (&event->x, &event->y);
   //g_debug("Marked %d\n", gui->movement->markstaffnum);
@@ -694,14 +786,23 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
                 {
                   gdouble end = Denemo.project->movement->end_time, start = Denemo.project->movement->start_time,
                   latest = ((DenemoObject*)pi.the_obj->data)->latest_time, earliest = ((DenemoObject*)pi.the_obj->data)->earliest_time;
-                  generate_midi();
+					
                   
                    if ((event->state & (GDK_CONTROL_MASK|GDK_MOD1_MASK)) == (GDK_CONTROL_MASK|GDK_MOD1_MASK)) //ALT+CONTROL drag to shift playback markers
                      {//g_print ("\nend %f and earliest %f", end, earliest);
+					  generate_midi();
                       if ((earliest>end) || (fabs(end-earliest) < fabs(latest-earliest) + 0.01))
-                        Denemo.dragging_end_playback_marker = TRUE;
+                        {
+							if (!Denemo.dragging_end_playback_marker)
+								playback_brightness_shift = drag_y;
+							Denemo.dragging_end_playback_marker = TRUE;
+						 }
                       else
-                         Denemo.dragging_start_playback_marker = TRUE;
+						{
+                         if (!Denemo.dragging_start_playback_marker)
+								playback_brightness_shift = drag_y;
+						 Denemo.dragging_start_playback_marker = TRUE;
+						}
                     }
                 }
              if (!(Denemo.dragging_end_playback_marker || Denemo.dragging_start_playback_marker)) 
@@ -711,6 +812,7 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
                     else
                       set_mark (NULL, NULL);
                     selecting = TRUE;
+                    
                   }
               }
             
@@ -725,6 +827,13 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
                   if (earliest < Denemo.project->movement->end_time)
                     Denemo.project->movement->start_time = earliest;
                fix_start_end_ordering ();
+                //g_print ("before event->y %d bright %d pbms %d\n", drag_y, Denemo.playback_marker_brightness, playback_brightness_shift);
+               Denemo.playback_marker_brightness += (playback_brightness_shift - drag_y);
+               if (Denemo.playback_marker_brightness>50) Denemo.playback_marker_brightness = 50;
+               if (Denemo.playback_marker_brightness<-50) Denemo.playback_marker_brightness = -50;
+               
+               playback_brightness_shift = drag_y;
+               //g_print ("after drag_y %d bright %d pbms %d\n", drag_y, Denemo.playback_marker_brightness, playback_brightness_shift);
             }
  
           if (event->state & (GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK))
@@ -776,7 +885,7 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
             gint key = gui->movement->maxkeywidth;
             gint cmajor = key ? 0 : 5;   
            
-            if (((gint) get_click_height (gui, event->y)<-10) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key))
+            if (((gint) get_click_height_on_closest_staff (gui, event->y)<-10) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key))
                  {   
                     struct placement_info pi;
                     if (event->y < 0)
@@ -798,7 +907,7 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
                     }
                 else if (event->x < (gui->leftmargin+35) + key + cmajor)   
                    {
-                       gint offset = (gint) get_click_height (gui, event->y);
+                       gint offset = (gint) get_click_height_on_closest_staff (gui, event->y);
                        if (offset > 0 && (offset < STAFF_HEIGHT / 2))  
                             Denemo.hovering_over_keysharpen = TRUE;
                        else if (offset > 0 && (offset < STAFF_HEIGHT))
@@ -820,22 +929,15 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
      if(pi.the_staff)
         {
           if ((gui->movement->leftmeasurenum > 1) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + gui->movement->maxkeywidth) && (event->x > gui->leftmargin))
-            {
              Denemo.hovering_over_left_arrow = TRUE;
-            }
-          else if (pi.nextmeasure)
-            {
-              if ((pi.at_edge) && ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend))))   
-                 Denemo.hovering_over_right_arrow = TRUE;
-             }
+          else 
+          if (Denemo.right_arrow_x && ((gint)event->x >= Denemo.right_arrow_x))
+             Denemo.hovering_over_right_arrow = TRUE;
+          else
+			  Denemo.hovering_over_left_arrow= Denemo.hovering_over_right_arrow = FALSE;
         }
  }   
-    
-    
-    
-    
-    
-    
+
   if ((oldm != Denemo.hovering_over_movement) 
   || (oldla != Denemo.hovering_over_left_arrow) 
   || (oldra != Denemo.hovering_over_right_arrow) 
@@ -856,7 +958,15 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
     get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
   else
     get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+    
+    //showing what object would become current if the user clicks
   GList *old_obj = Denemo.object_hovering_over;
+  
+  if(gui->movement->recording && (event->y < HeightOfRecordingTrack*gui->movement->zoom))
+	{
+		return TRUE;
+	}
+  
   Denemo.object_hovering_over = pi.the_obj;
   if (old_obj != Denemo.object_hovering_over)
     gtk_widget_queue_draw (Denemo.scorearea);
@@ -919,13 +1029,16 @@ gboolean activate_right_click (gint state)
         }
      return FALSE;
     }
+    
+
 /**
  * Mouse button press callback
  *
  */
 gint
 scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
-{
+{ 
+	//g_print ("press with state %x\n", event->state);
   DenemoProject *gui = Denemo.project;
   if (gui == NULL || gui->movement == NULL)
     return FALSE;
@@ -948,41 +1061,120 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
         return TRUE;
       }
   dragging_separator = FALSE;
+  
+   if (dragging_display == FALSE)
+    if (left && (event->state == GDK_CONTROL_MASK))
+      {
+        if (Denemo.prefs.learning)
+          MouseGestureShow(_("Dragging measure width/staff spacing."), _("This will widen/narrow the measures/staffs in the display."),
+            MouseGesture);
+        dragging_display = TRUE;
+        static gboolean done;
+        if (!done)
+			{
+				done = TRUE;
+				assign_cursor ( 99, GDK_CROSS);
+			}
+        set_cursor_for (99);
+        return TRUE;
+      }
+  dragging_display = FALSE; 
+  drag_display_x = -1;//to reset
+  
+  
+  if (gui->movement->top_staff == 1)
+	{
+	  if(gui->movement->recording && gui->movement->recording->type==DENEMO_RECORDING_AUDIO)
+		{
+		 //g_debug("audio %f %f\n", event->x, event->y);
+		  if(event->y < HeightOfRecordingTrack*gui->movement->zoom /* see draw.c for this value, the note onsets are drawn in the top 20 pixels */)
+			{
+				if (event->type==GDK_2BUTTON_PRESS)
+					{
+						gui->movement->recording->marked_onset_position = (gint)event->x/gui->movement->zoom;
+						if (gui->movement->recording->marked_onset_position < (gui->leftmargin+35) + SPACE_FOR_TIME + gui->movement->maxkeywidth) {
+							 if (Denemo.prefs.learning)
+								MouseGestureShow(_("Double Click Note Onset"), _("This represents detected note onsets which occur\nbefore the start of the score.\nIf they are just noise,\nor if you are working on just a portion of the audio that is ok.\nOtherwise drag with left mouse button to synchronize\nwith the start of the score."),
+													MouseGesture);
+							}
+						else if (Denemo.prefs.learning)
+								MouseGestureShow(_("Double Click Recorded MIDI Note"), _("This marks/un-marks the current recorded MIDI note."),
+			  MouseGesture);
+						gtk_widget_queue_draw(Denemo.scorearea);//sets marked_onset to match marked_onset_position
+						return TRUE;
+					} 
+			  else
+					{
+						if (is_playing ())
+							{
+								g_warning ("Stop playing first");
+								return TRUE;
+							}
+						
+						//gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), left?Denemo.GDK_SB_H_DOUBLE_ARROW:Denemo.GDK_X_CURSOR);
+						left? (dragging_recording_sync = TRUE) : (dragging_tempo = TRUE);
+						motion_started = FALSE;
+						
+						if (Denemo.prefs.learning) 
+						 left? 	MouseGestureShow(_("Left on Note Onset"), _("preparing to drag..."),
+												MouseGesture) :
+								MouseGestureShow(_("Start Playing Recording"), _("This starts playing the recorded MIDI notes from the marked onset"),
+												MouseGesture);
+						
+						gtk_widget_queue_draw(Denemo.scorearea);
+						return TRUE;
+					}
+			}
+		} //end of Audio
+	   else  if(gui->movement->recording && (gui->movement->recording->type==DENEMO_RECORDING_MIDI) && (event->y < HeightOfRecordingTrack*gui->movement->zoom) && midi_track_present ())
+		{
+			if (left)
+				{
+					
+					if (control_held_down () && shift_held_down ())
+						{
+							gui->movement->recording->marked_onset_position = (gint)event->x/gui->movement->zoom;
+							play_recorded_midi ();//toggles
+							if (Denemo.prefs.learning) 
+								 MouseGestureShow(_("Control-Shift Left click on MIDI Recording Track"), _("Starts/Stops playback of recorded MIDI from marked note."),
+														MouseGesture);
+						} else
+					if (control_held_down ())
+						{
+							dragging_tempo = TRUE;
+							motion_started = FALSE;
+							if (Denemo.prefs.learning) 
+								 MouseGestureShow(_("Control Left click on MIDI Recording Track"), _("Start dragging to change tempo of MIDI recorded track."),
+														MouseGesture);
+						} else
+					if (shift_held_down ())
+						{
 
-  if(gui->movement->recording)
-    {
-     //g_debug("audio %f %f\n", event->x, event->y);
-
-
-      if(event->y < 20*gui->movement->zoom /* see draw.c for this value, the note onsets are drawn in the top 20 pixels */)
-        {
-            if (event->type==GDK_2BUTTON_PRESS)
-                {
-                    gui->movement->marked_onset_position = (gint)event->x/gui->movement->zoom;
-                    if(gui->movement->marked_onset_position < (gui->leftmargin+35) + SPACE_FOR_TIME + gui->movement->maxkeywidth) {
-                         if (Denemo.prefs.learning)
-                            MouseGestureShow(_("Double Click Note Onset"), _("This represents detected note onsets which occur\nbefore the start of the score.\nIf they are just noise,\nor if you are working on just a portion of the audio that is ok.\nOtherwise drag with left mouse button to synchronize\nwith the start of the score."),
-          MouseGesture);
-
-                    }
-                    gtk_widget_queue_draw(Denemo.scorearea);
-                    return TRUE;
-                } else
-                {
-                    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), left?Denemo.GDK_SB_H_DOUBLE_ARROW:Denemo.GDK_X_CURSOR);
-                    left? (dragging_audio = TRUE) : (dragging_tempo = TRUE);
-                     if (Denemo.prefs.learning)
-                     left? MouseGestureShow(_("Left Drag Note Onset"), _("This moves the audio to synchronize the start with the score.\nYou can use the Leadin button for this too."),
-          MouseGesture) :
-                        MouseGestureShow(_("Right Drag Note Onset"), _("This changes the tempo of the score.\nUse this to synchronize the beat after setting the start"),
-          MouseGesture);
-                    gtk_widget_queue_draw(Denemo.scorearea);
-                    return TRUE;
-                }
-        }
-
-    }
-
+							dragging_recording_sync = TRUE;
+							motion_started = FALSE;
+							if (Denemo.prefs.learning) 
+								 MouseGestureShow(_("Shift Left click on MIDI Recording Track"), _("Drag the marked MIDI note to synchronize to a place in the score."),
+														MouseGesture);
+						} else
+						{
+							gui->movement->recording->marked_onset_position = (gint)event->x/gui->movement->zoom;
+							pause_recording_midi ();//ensures further recording does not leave a long gap if the user has recording long rests enabled
+							if (Denemo.prefs.learning)
+								MouseGestureShow(_("Left Click Recorded MIDI Note"), _("This marks the current recorded MIDI note."),
+			  MouseGesture);
+						}
+					return TRUE;
+				}
+			else
+				{
+					if (Denemo.prefs.learning) 
+						 MouseGestureShow(_("Right click on MIDI Recording Track"), _("Menu of options for MIDI recorded track."),
+												MouseGesture);
+					popup_menu ("Recording");
+					return TRUE;
+				}
+		}
+  }
 
   //g_debug("before %f %f\n", event->x, event->y);
   transform_coords (&event->x, &event->y);
@@ -1056,31 +1248,21 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       draw_score_area();
       return TRUE;
     }
-  else if (pi.nextmeasure)
+  else
     {
-      if ((pi.at_edge) && ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend))))//crashed here with the_obj 0x131 !!!
+      if (Denemo.hovering_over_right_arrow)
         {
-          if ((gui->movement->currentmeasurenum != gui->movement->rightmeasurenum) &&
-                (!set_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
-              set_currentmeasurenum (gui, gui->movement->rightmeasurenum);
-          else if ((gui->movement->cursor_appending) &&
-                (!set_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
-              set_currentmeasurenum (gui, gui->movement->rightmeasurenum);
+		if (gui->movement->currentmeasure && gui->movement->currentmeasure->next)
+			set_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1);
+		if (Denemo.prefs.learning)
+		  MouseGestureShow(_("Press Left."), _("This moved the cursor to the measure off-screen right. That measure becomes the second from the left."),
+			MouseGesture);
+		write_status (gui);
+		return TRUE;
 
-
-
-
-          if (gui->movement->currentmeasurenum != gui->movement->rightmeasurenum) {
-            if (Denemo.prefs.learning)
-              MouseGestureShow(_("Press Left."), _("This moved the cursor to the measure off-screen right. The display is shifted to move the cursor to the middle."),
-                MouseGesture);
-          write_status (gui);
-          return TRUE;
-        }
         }
     }
 
-
   if (pi.the_measure != NULL)
     {                           /*don't place cursor in a place that is not there */
       //gui->movement->currentstaffnum = pi.staff_number;
@@ -1094,8 +1276,8 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       if (event->type==GDK_2BUTTON_PRESS)
                 {
                     if(gui->movement->recording &&  !g_strcmp0 (((DenemoStaff *) gui->movement->currentstaff->data)->denemo_name->str, DENEMO_CLICK_TRACK_NAME))
-                        {
-                            gui->movement->marked_onset_position = (gint)event->x/gui->movement->zoom;
+                        {//FIXME this is never reached as we don't allow the mouse to access the click track 
+                            gui->movement->recording->marked_onset_position = (gint)event->x/gui->movement->zoom;
                             if (Denemo.prefs.learning)
                                 MouseGestureShow(_("Double Click on Click Track"), _("This will mark the MIDI note onset."), MouseGesture);
                             return TRUE;
@@ -1325,15 +1507,36 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
   if(Denemo.dragging_end_playback_marker || Denemo.dragging_start_playback_marker)
     {
       Denemo.dragging_start_playback_marker = Denemo.dragging_end_playback_marker = FALSE;
+      playback_brightness_shift = 0;
       gui->movement->markstaffnum = 0;
     }
   gboolean left = (event->button != 3);
-  if(gui->movement->recording && (dragging_tempo || dragging_audio))
+  if(gui->movement->recording && (dragging_tempo || dragging_recording_sync))
     {
-            dragging_tempo = dragging_audio = FALSE;
-            gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
+		//g_print ("button release -  current object = 0x%p dragging sync %d or tempo %d\n", gui->movement->currentobject, dragging_recording_sync, dragging_tempo);
+        if (motion_started)
+			{
+				if (gui->movement->recording && gui->movement->recording->type == DENEMO_RECORDING_MIDI)
+					{
+						if(dragging_recording_sync)
+							{
+								Denemo.project->movement->recording->sync = NULL;
+							    synchronize_recording ();//changes leadin only
+							}
+						else
+							//g_print ("Scaling Done\n");//this should stretch or squash the timings in Denemo.project->recording->notes keeping any marked offset at the same time
+							;//do nothing
+						dragging_tempo = dragging_recording_sync = FALSE;
+						return TRUE;
+					}
+				else
+				gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
+			}
+            
+            dragging_tempo = dragging_recording_sync = FALSE;
             return TRUE;
     }
+    
   if (dragging_separator)
     {
       if (Denemo.prefs.learning)
@@ -1342,7 +1545,20 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
       dragging_separator = FALSE;
       return TRUE;
     }
+    
+  if (dragging_display)
+    {
+      dragging_display = FALSE;
+      return TRUE;
+    }
+     
+    
+    
 
+	if(gui->movement->recording && (event->y < HeightOfRecordingTrack*gui->movement->zoom) && midi_track_present ())
+	{
+		return TRUE;
+	}
   //g_signal_handlers_block_by_func(Denemo.scorearea, G_CALLBACK (scorearea_motion_notify), gui);
   if (left)
     lh_down = FALSE;
@@ -1364,7 +1580,7 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
     return FALSE;
   switch (event->direction)
     {
-      DenemoScriptParam param;
+    DenemoScriptParam param;//for testing move to staffup/down
     case GDK_SCROLL_UP:
       if (event->state & GDK_CONTROL_MASK)
         {
@@ -1390,14 +1606,17 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
             gint command_idx = lookup_command_from_name(Denemo.map, "MoveToStaffUp");
             KeyStrokeShow (_("Unshifted + Mouse Wheel Up"), command_idx, TRUE);
           }
-          movetostaffup (NULL, &param);
-          if (!param.status) {
-            DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->currentstaff->data);
-            if(thestaff->space_above < MAXEXTRASPACE)
-              {
-                thestaff->space_above++;
-                g_debug ("Increasing the height of the top staff");
-              }
+         if (!(midi_track_present () && Denemo.project->movement->currentstaff == Denemo.project->movement->thescore->next))
+			{
+				movetostaffup (NULL, &param);
+				if (!param.status) { //i.e. movetostaffup failed
+				DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->currentstaff->data);
+				if(thestaff->space_above < MAXEXTRASPACE)
+				  {
+					thestaff->space_above++;
+					g_debug ("Increasing the height of the top staff");
+				  }
+			  }
           }
         }
       break;
@@ -1430,11 +1649,12 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
           }
           movetostaffdown (NULL, &param);
           if (!param.status) {
-            warningmessage ("This is the bottom staff");
-           // DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->currentstaff->data);
-           // thestaff->space_below++; //This doesn't help, because the viewport does not change.
-           // warningmessage ("Increasing the space below the bottom staff");
-           //move_viewport_down(Denemo.project);
+			  DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->thescore->data);
+				if((thestaff->space_above > 0))
+				  {
+					thestaff->space_above--;
+					g_debug ("Decreasing the height of the top staff");
+				  }
           }
         }
       break;
