@@ -58,13 +58,14 @@ struct callbackdata
   GtkWidget *lastmeasure;
   GtkWidget *laststaff;
   GtkWidget *pitchspellingchannel;
-  GtkWidget *pitchspellingprogram;
+  GtkWidget *use_pitchspelling;
   GtkWidget *cursor_highlight;
   GtkWidget *return_key_is_special;
   GtkWidget *newbie;
   GtkWidget *learning;
   GtkWidget *persistence;
   GtkWidget *startmidiin;
+  GtkWidget *recording_timeout;
   GtkWidget *notesonlymidiin;
   GtkWidget *applytoselection;
   GtkWidget *quickshortcuts;
@@ -133,6 +134,7 @@ struct callbackdata
   GtkWidget *profile;
   GtkWidget *midiplayer;
   GtkWidget *graphicseditor;
+  GtkWidget *ghostscript;
   GtkWidget *fontname;
   GtkWidget *fontsize;
   GtkWidget *denemopath;
@@ -236,6 +238,7 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNTEXT (browser)
   ASSIGNTEXT (imageviewer)
   ASSIGNTEXT (graphicseditor)
+  ASSIGNTEXT (ghostscript)
   ASSIGNTEXT (username)
   //ASSIGNTEXT (password)
   ASSIGNTEXT (profile)
@@ -300,6 +303,7 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNINT (maxhistory)
     ASSIGNBOOLEAN (damping)
     ASSIGNINT (dynamic_compression)
+    ASSIGNINT (recording_timeout)
     ASSIGNINT (zoom)
     ASSIGNINT (system_height)
     ASSIGNBOOLEAN (immediateplayback)
@@ -314,7 +318,7 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNINT (lastmeasure)
     ASSIGNINT (laststaff)
     ASSIGNINT (pitchspellingchannel)
-    ASSIGNINT (pitchspellingprogram)
+    ASSIGNBOOLEAN (use_pitchspelling)
 
     ASSIGNBOOLEAN (persistence)
     ASSIGNBOOLEAN (cursor_highlight)
@@ -626,6 +630,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   TEXTENTRY (_("File/Internet Browser"), browser)
   TEXTENTRY (_("Image Viewer"), imageviewer)
   TEXTENTRY (_("Graphics Editor"), graphicseditor)
+  TEXTENTRY (_("Ghostscript"), ghostscript)
   TEXTENTRY (_("Default Save Path"), denemopath)
   BOOLEANENTRY (_("Update the command set on startup"), autoupdate);
   /*
@@ -693,7 +698,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   BOOLEANENTRY (_("Play back entered notes immediately"), immediateplayback);
   INTENTRY_LIMITS (_("MIDI key sound on measure end\n  (0 = Off)"), measureswitchsound, 0, 127);
   INTENTRY_LIMITS (_("Pitch Spelling Channel"), pitchspellingchannel, 0, 15);
-  INTENTRY_LIMITS (_("Pitch Spelling Program"), pitchspellingprogram, 0, 127);
+  BOOLEANENTRY (_("Use Pitch Spelling"), use_pitchspelling);
 
 
   INTENTRY_LIMITS (_("% MIDI-in Dynamic Compression"), dynamic_compression, 0, 100);
@@ -762,6 +767,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   driver = g_list_nth_data (cbdata.midi_driver_option_list, index);
 
   NEWPAGE (_("MIDI"));
+  INTENTRY_LIMITS (_("% MIDI-in recording timeout (ms)"), recording_timeout, 100, 10000);
 
   BOOLEANENTRY (_("Rhythm Entry for MIDI in"), startmidiin);
   BOOLEANENTRY (_("Ignore MIDI in except for Note On/Off messages"), notesonlymidiin);
