@@ -145,8 +145,7 @@ deleteSchemeText (void)
  Denemo.project->has_script = FALSE;
 }
 
-void
-appendSchemeText (gchar * text)
+void appendSchemeText (gchar * text)
 {
   if(!Denemo.non_interactive){
     GtkTextIter enditer;
@@ -236,11 +235,17 @@ save_scheme_text (GtkWidget * widget, GtkWidget * textview)
           warningdialog (_ ("If you have loaded this script from a menu item or palette button then you must save it using a right click on that same menu item or palette button (and choosing \"Save Script from Scheme Window\").\nOtherwise use \"Save As\" from this menu."));
         }
   else
-    {
+    { 
+		
       gchar *text = get_script_view_text ();
-      buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (Denemo.script_view));
-      g_file_set_contents (*pfilename, text, -1, NULL);
-      gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (buffer), FALSE);
+      		if (confirm (*pfilename, (text && *text) ? _("Overwrite this file?") : _("Blank out this file?")))
+      		{
+			  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (Denemo.script_view));
+			  g_file_set_contents (*pfilename, text, -1, NULL);
+			  gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (buffer), FALSE);
+			  infodialog (_("Saved File"));
+			 } else
+			 warningdialog (_("Cancelled"));
       g_free (text);
     }
 }
@@ -426,6 +431,9 @@ create_editor_window (void)
   gtk_window_set_title (GTK_WINDOW (w), _("Denemo Scheme Script"));
   //gtk_window_set_resizable (GTK_WINDOW (w), TRUE);
   g_signal_connect (G_OBJECT (w), "delete-event", G_CALLBACK (hide_scheme /*gtk_widget_hide_on_delete */ ), w);
+  g_signal_connect (G_OBJECT (SchemeWindow), "key_press_event", G_CALLBACK (window_keypress_event), NULL);
+
+  
   GtkWidget *main_vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_add (GTK_CONTAINER (w), main_vbox);
 
